<?php

namespace App\Http\Controllers\Api\Clientas;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Database\QueryException;
use App\Models\Clients;
use App\Models\GeneralData;
use Illuminate\Support\Facades\File;

class ClientasController extends Controller {
    public function getClientas() {
        $response = array(
            "error" => false,
            "message" => "Sin error"
        );

        try {
            $clientas = DB::table("clients")
            ->select("clients.id", 
                "clients.fullname",
                "clients.email",
                DB::Raw("COALESCE(programs.name, '') as nutrition_plan"),
                DB::Raw("COALESCE(workouts.program, '') as workout_plan"),
                DB::Raw("DATE_FORMAT(clients.created_at, '%d/%m/%Y') as created_at"), 
                DB::Raw("CASE 
                	WHEN clients.status < 1 THEN 'Inactiva'
                	WHEN clients.status > 0 THEN 'Activa'
                END as status"), 
                DB::Raw("COALESCE(suscriptions.name, '') as suscription_plan")
            )
            ->leftJoin("programs", "clients.nutrition_plan", "=", "programs.id")
            ->leftJoin("workouts", "clients.workout_plan", "=", "workouts.id")
            ->leftJoin("suscriptions", "clients.suscription_plan", "=", "suscriptions.id")
            ->orderBy("created_at", "DESC")
            ->get();

            $response = array(
                "error" => true,
                "message" => "Sin error", 
                "data" => $clientas
            );
        } catch ( QueryException $e ) {
            $response = array(
                "error" => true,
                "message" => "Error en la consulta", 
                "data" => $e->getMessage()
            );
        }

        return response()
            ->json($response, 200)
            ->header("Access-Control-Allow-Origin", "*");
    }
}
