<?php

namespace App\Http\Controllers\Api\Integraciones\Calorias;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Database\QueryException;
use App\Models\Clients;
use App\Models\GeneralData;
use App\Models\HealthyPregnancy;
use App\Models\HealthyPostpartum;
use App\Models\HealthyLactation;
use App\Models\MainGoal;
use App\Models\HormonalDisorders;
use App\Models\GoalWeight;
use App\Models\PhysicalActivity;
use App\Models\Suscriptions;
use App\Models\TrackingWeight;
use App\Models\CaloriesControl;
use DateTime;

use PHPMailer\PHPMailer\PHPMailer;
use PHPMailer\PHPMailer\SMTP;
use PHPMailer\PHPMailer\Exception;

class CaloriasController extends Controller {
    private function obtener_edad_segun_fecha($fecha_nacimiento) {
        $nacimiento = new DateTime($fecha_nacimiento);
        $ahora = new DateTime(date("Y-m-d"));
        $diferencia = $ahora->diff($nacimiento);
        return $diferencia->format("%y");
    }

    protected function calcularCalorias ( $cliente ) {
        try {
            $restResponse = 200;

            $energia = 0;
            $extra = 0;

            $Clients = Clients::select("nutrition_plan")->where("id", $cliente)->first();
            $GeneralData = GeneralData::where("i_client", $cliente)->orderBy("id", "DESC")->first();

            if ( $GeneralData ) {
                $HealthyPregnancy = HealthyPregnancy::where('i_client', $cliente)->first();
                $HealthyPostpartum = HealthyPostpartum::where('i_client', $cliente)->first();
                $HealthyLactation = HealthyLactation::where('i_client', $cliente)->first();

                $pesoTracking = TrackingWeight::where("i_client", $cliente)->orderBy("id", "DESC")->first();

                if ( $GeneralData['weight_unit'] == 2 ) {
                    if ( $pesoTracking != null && isset($pesoTracking['weight']) ) {
                        $pesoKilos = $pesoTracking['weight'] * 0.45;
                    } else {
                        $pesoKilos = $GeneralData['weight'] * 0.45;
                    }
                } else {
                    if ( $pesoTracking != null && isset($pesoTracking['weight']) ) {
                        $pesoKilos = $pesoTracking['weight'];
                    } else {
                        $pesoKilos = $GeneralData['weight'];
                    }
                }

                $alturaMetros = $GeneralData['height'] / 100; 
                $IMC = $pesoKilos / ($alturaMetros*$alturaMetros);

                $edad = $this->obtener_edad_segun_fecha($GeneralData['birth_date']);
                if ( $IMC >= 18.5 && $IMC <= 24.5 ) {
                    $pesoIdeal = ($alturaMetros*$alturaMetros);
                } elseif ( $IMC < 18.5 ) {
                    $pesoIdeal = ($alturaMetros*$alturaMetros) * 21.5;
                } elseif ( $IMC > 24.5 ) {
                    $pesoIdeal = ($alturaMetros*$alturaMetros) * 24.9;
                }

                
                if( $HealthyPregnancy != null ) {
                    if ( $HealthyPregnancy['weeks'] >= 0 && $HealthyPregnancy['weeks'] <= 12 ) {
                        $energia = 0;
                    } elseif ( $HealthyPregnancy['weeks'] >= 13 && $HealthyPregnancy['weeks'] <= 24 ) {
                        $energia = 340;
                    } elseif ( $HealthyPregnancy['weeks'] >= 25 && $HealthyPregnancy['weeks'] <= 36 ) {
                        $energia = 452;
                    }

                    if ( $HealthyPregnancy['babys'] > 1 ) {
                        $extra = ($HealthyPregnancy['babys']-1) * 150;
                    }

                    $calculo = ( (10 * $HealthyPregnancy->weight ) + ( 6.25 * ( $alturaMetros * 100 ) ) - ( 5 * $edad ) - 161 ) + $energia + $extra;

                    $nearest = ceil($calculo);
                    if ( substr($nearest, -2) < 50 ) {
                        $calorias = floor(number_format($calculo, 0, '.', '')/100)*100;
                    } else {
                        $calorias = ceil(number_format($calculo, 0, '.', '')/100)*100;
                    }

                    return $calorias;
                } elseif ( $HealthyPostpartum != null ) {
                    $calculo = ( (10 * $HealthyPostpartum->weight ) + ( 6.25 * ( $alturaMetros * 100 ) ) - ( 5 * $edad ) - 161 );
                    $IMC = $HealthyPostpartum->weight / ($alturaMetros*$alturaMetros);

                    if ( $IMC < 18.5 ) {
                        $calculo = $calculo + 500;
                    } elseif ( $IMC >= 18.5 && $IMC <= 24.9 ) {
                        $calculo = $calculo + 330;
                    } 

                    $nearest = ceil($calculo);
                    if ( substr($nearest, -2) < 50 ) {
                        $calorias = floor(number_format($calculo, 0, '.', '')/100)*100;
                    } else {
                        $calorias = ceil(number_format($calculo, 0, '.', '')/100)*100;
                    }

                    return $calorias;
                } elseif ( $HealthyLactation != null ) {
                    $calculo = ( (10 * $HealthyLactation->weight ) + ( 6.25 * ( $alturaMetros * 100 ) ) - ( 5 * $edad ) - 161 );
                    $IMC = $HealthyLactation->weight / ($alturaMetros*$alturaMetros);

                    if ( $IMC < 18.5 ) {
                        $calculo = $calculo + 500;
                    } elseif ( $IMC >= 18.5 && $IMC <= 24.9 ) {
                        $calculo = $calculo + 330;
                    } 

                    $nearest = ceil($calculo);
                    if ( substr($nearest, -2) < 50 ) {
                        $calorias = floor(number_format($calculo, 0, '.', '')/100)*100;
                    } else {
                        $calorias = ceil(number_format($calculo, 0, '.', '')/100)*100;
                    }

                    return $calorias;
                }

                switch ( $GeneralData['physical_activity'] ) {
                    case 1: //Sedentaria
                        $AF = 1;
                        break;
                    case 2: // Ligeramente activa
                        $AF = 1.05;
                        break;
                    case 3: // Activa
                        $AF = 1.1;
                        break;
                    case 4: // Muy activa
                        $AF = 1.2;
                        break;
                    default :
                        $AF = 1;
                        break;
                }

                // No tomnar en cuenta Mifflin
                switch ( $GeneralData['weight_goal'] ) {
                    case 1: //Aumento de peso
                        if ( $IMC >= 24.9 ) {
                            $base = 25;
                        } else {
                            $base = 30;
                        }
                        $calculo =  ( $base * $pesoKilos ) * $AF;
                        $nearest = ceil($calculo);
                        if ( substr($nearest, -2) < 50 ) {
                            $calorias = floor(number_format($calculo, 0, '.', '')/100)*100;
                        } else {
                            $calorias = ceil(number_format($calculo, 0, '.', '')/100)*100;
                        }
                        return $calorias;
                        break;
                    case 2: // Bajar de peso, si IMC es bajo mandar 6 
                        if ( $IMC >= 18.5 ) {
                            $calculo = ( (10 * $pesoKilos ) + ( 6.25 * ( $alturaMetros * 100 ) ) - ( 5 * $edad ) - 161 );
                            $calculo = ( $calculo * 1.2 ) - 500;
                            $nearest = ceil($calculo);
                            if ( substr($nearest, -2) < 50 ) {
                                $calorias = floor(number_format($calculo, 0, '.', '')/100)*100;
                            } else {
                                $calorias = ceil(number_format($calculo, 0, '.', '')/100)*100;
                            }

                            if ( $calorias > 1800 ) {
                                $calorias = 1800;
                            }

                            GeneralData::where("i_client", $cliente)->update(['calories' => $calorias]); 

                            return $calorias;
                        } else {
                           $calculo =  ( 25 * $pesoKilos );
                           $nearest = ceil($calculo);
                            if ( substr($nearest, -2) < 50 ) {
                                $calorias = floor(number_format($calculo, 0, '.', '')/100)*100;
                            } else {
                                $calorias = ceil(number_format($calculo, 0, '.', '')/100)*100;
                            }

                            if ( $calorias > 1800 ) {
                                $calorias = 1800;
                            }

                            GeneralData::where("i_client", $cliente)->update(['calories' => $calorias]);

                            return $calorias;
                        }
                        break; 
                    case 3: // Aumento de grasa corporal
                        if ( $IMC >= 24.9 ) {
                            $base = 25;
                        } else {
                            $base = 30;
                        }
                        $calculo =  ( $base * $pesoKilos ) * $AF;
                        $nearest = ceil($calculo);
                        if ( substr($nearest, -2) < 50 ) {
                            $calorias = floor(number_format($calculo, 0, '.', '')/100)*100;
                        } else {
                            $calorias = ceil(number_format($calculo, 0, '.', '')/100)*100;
                        }
                        return $calorias;
                        break;
                    case 4: // Aumento de músculo
                        if ( $IMC >= 24.9 ) {
                            $base = 25;
                        } else {
                            $base = 30;
                        }
                        $calculo =  ( $base * $pesoKilos ) * $AF;
                        $nearest = ceil($calculo);
                        if ( substr($nearest, -2) < 50 ) {
                            $calorias = floor(number_format($calculo, 0, '.', '')/100)*100;
                        } else {
                            $calorias = ceil(number_format($calculo, 0, '.', '')/100)*100;
                        }
                        return $calorias;
                        break;
                    case 5: // Mantenimiento de peso
                        if ( $IMC >= 24.9 ) {
                            $AF = 1;
                        }
                        $calculo =  ( 25 * $pesoKilos ) * $AF;
                        $nearest = ceil($calculo);
                        if ( substr($nearest, -2) < 50 ) {
                            $calorias = floor(number_format($calculo, 0, '.', '')/100)*100;
                        } else {
                            $calorias = ceil(number_format($calculo, 0, '.', '')/100)*100;
                        }
                        return $calorias;
                        break;
                    case 6: // Recomposición corporal
                        if ( $IMC >= 24.9 ) {
                            $AF = 1;
                        }
                        $calculo =  ( 25 * $pesoKilos ) * $AF;
                        $nearest = ceil($calculo);
                        if ( substr($nearest, -2) < 50 ) {
                            $calorias = floor(number_format($calculo, 0, '.', '')/100)*100;
                        } else {
                            $calorias = ceil(number_format($calculo, 0, '.', '')/100)*100;
                        }

                        return $calorias;
                        break;
                }
            } else {
                return "no data";
            }
        } catch (QueryException $e) {
            $restResponse = 500;
            $response = array(
                "error" => true,
                "message" => "No se pudo encontrar información", 
                "data" => $e->getMessage()
            );
        }
    }

    public function updateCalorias ( Request $r ) {
        if ( Request()->header('x-glowme-key') != $_ENV['X_GLOWME_API'] ) { 
            return response()
            ->json([ 
                'error' => true, 
                'message' => "Api key error", 
                'data' => "Acceso no permitido" 
            ], 403)
            ->header("Access-Control-Allow-Origin", "*");
        } else {
            try {
                $restResponse = 200;

                $calculo = $this->calcularCalorias($r->cliente);

                if ( $calculo == "no data" ) {
                    $response = array(
                        "error" => false,
                        "message" => "calculo de calorias antes de cuestionario, sin datos", 
                        "data" => []
                    );
                    return response()
                        ->json($response, $restResponse)
                        ->header("Access-Control-Allow-Origin", "*");
                }
                
                if ( $calculo < 1100 ) {
                    $newCalories = 1100;
                } elseif ( $calculo = 1900 ) {
                    $newCalories = 1800;
                } elseif ( $calculo == 2100 ) {
                    $newCalories = 2000;    
                } elseif ( $calculo == 2200 ) {
                    $newCalories = 2300;    
                } elseif ( $calculo = 2400 ) {
                    $newCalories = 2300;
                } elseif ( $calculo = 2500 ) {
                    $newCalories = 2600;
                } elseif ( $calculo > 2600 ) {
                    $newCalories = 2600;
                } else {
                    $newCalories = $calculo;
                }
                

                $control = CaloriesControl::where("i_client", $r->cliente)->first();
                if ( $control == null ) {
                    $CaloriesControl = new CaloriesControl();
                    $CaloriesControl->i_client = $r->cliente;
                    $CaloriesControl->calories = $newCalories;
                    $CaloriesControl->save();
                    GeneralData::where("i_client", $r->cliente)->update(['calories' => $newCalories]);
                } else {
                    $date1 = new DateTime();
                    $date2 = new DateTime($control['updated_at']);
                    $diff = $date1->diff($date2);                          
                    if ( $diff->days > 29 ) {
                        CaloriesControl::where("i_client", $r->cliente)->update(["calories" => $newCalories]);
                        GeneralData::where("i_client", $r->cliente)->update(['calories' => $newCalories]);
                    }
                }

                $response = array(
                    "error" => false,
                    "message" => "Consulta exitosa", 
                    "data" => $newCalories
                );
            } catch (QueryException $e) {
                $restResponse = 500;
                $response = array(
                    "error" => true,
                    "message" => "No se pudo encontrar información", 
                    "data" => $e->getMessage()
                );
            }

            return response()
                ->json($response, $restResponse)
                ->header("Access-Control-Allow-Origin", "*");
        }
    }
}