<?php

namespace App\Http\Controllers\Api\Integraciones\Graficos;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Database\QueryException;
use App\Models\GeneralData;
use App\Models\TrackingWeight;
use App\Models\TrackingWater;
use App\Models\TrackingExercise;
use App\Models\TrackingNutrition;
use App\Models\TrackingSleep; 
use App\Models\TrackingMood;
use App\Models\CatMood;
use App\Models\TrackingEnergy;
use App\Models\TrackingSupplements;
use App\Models\CatSupplements;
use App\Models\TrackingMeditation;
use App\Models\TrackingMenstrualCycle;
use DateTime;

class GraficosController extends Controller {
	protected $unidades = array( 1 => "Litros", 2 => "Mililitros", 3 => "Galones", 4 => "Onzas" );
	protected $unidadesPeso = array( 1 => "Kilos", 2 => "Libras" );
	protected $unidadesDistancia = array( 3 => "Centimetros", 4 => "Pulgadas" );

    public function getMedidas( Request $r ) {
        if ( Request()->header('x-glowme-key') != $_ENV['X_GLOWME_API'] ) { 
            return response()
            ->json([ 
                'error' => true, 
                'message' => "Api key error", 
                'data' => "Acceso no permitido" 
            ], 403)
            ->header("Access-Control-Allow-Origin", "*");
        } else {
            try {
            	$GeneralData = GeneralData::select("weight_unit", "waist_unit", "hip_unit")->where("i_client", $r->cliente)->first();
                $TrackingWeight = TrackingWeight::select( 
                    "weight", 
                    "waist", 
                    "hip", 
                    "date_at", 
                    DB::Raw( "DATE(date_at) as fecha" ) 
                )
                ->where("i_client", $r->cliente)
                ->groupBy( "fecha" )
                ->orderBy("date_at")
                ->orderBy("id", "desc")
                ->get();

                $resultPeso = array();
                foreach ( $TrackingWeight as $item ) {
                	$resultPeso["peso"][] = array(
                		"date" => date("d-m-Y", strtotime($item['date_at'])), 
                		"peso" => number_format($item['weight'], '0'), 
                		"unidad" => $this->unidadesPeso[$GeneralData['weight_unit']]
                	);
                	$resultPeso["cintura"][] = array(
                		"date" => date("d-m-Y", strtotime($item['date_at'])), 
                		"cintura" => number_format($item['waist'], '0'), 
                		"unidad" => $this->unidadesDistancia[$GeneralData['waist_unit']]
                	);
                	$resultPeso["cadera"][] = array(
                		"date" => date("d-m-Y", strtotime($item['date_at'])), 
                		"cadera" => number_format($item['hip'], '0'), 
                		"unidad" => $this->unidadesDistancia[$GeneralData['hip_unit']]
                	);
                }

                $restResponse = 200;
                $response = array(
                    "error" => false,
                    "message" => "Consulta exitosa", 
                    "data" => $resultPeso
                );
            } catch (QueryException $e) {
                $restResponse = 500;
                $response = array(
                    "error" => true,
                    "message" => "Error en la consulta", 
                    "data" => $e->getMessage()
                );
            }

            return response()
                ->json($response, $restResponse)
                ->header("Access-Control-Allow-Origin", "*");
        }
    }

    public function getAgua( Request $r ) {
        if ( Request()->header('x-glowme-key') != $_ENV['X_GLOWME_API'] ) { 
            return response()
            ->json([ 
                'error' => true, 
                'message' => "Api key error", 
                'data' => "Acceso no permitido" 
            ], 403)
            ->header("Access-Control-Allow-Origin", "*");
        } else {
            try {
            	// 1.- Litros, 2.- Mililitros, 3.- Galones, 4.- Onzas

            	$TrackingWaterUnit = TrackingWater::select( "i_unit")->where("i_client", $r->cliente)->first();
                
                $TrackingWater = TrackingWater::select( 
                	DB::Raw( "SUM(water) as water" ), 
                	DB::Raw( "Date(date_at) as fecha" ) 
                )->where("i_client", $r->cliente)
                ->orderBy("fecha")
                ->groupBy("fecha")
                ->get()
                ->toArray();

                $result = array();
                foreach ( $TrackingWater as $item ) {
                	$result[] = array(
                		"date" => date("d-m-Y", strtotime($item['fecha'])), 
                		"agua" => number_format($item['water'], '0'), 
                		"unidad" => $this->unidades[$TrackingWaterUnit['i_unit']]
                	);
                }

                $restResponse = 200;
                $response = array(
                    "error" => false,
                    "message" => "Consulta exitosa", 
                    "data" => $result
                );
            } catch (QueryException $e) {
                $restResponse = 500;
                $response = array(
                    "error" => true,
                    "message" => "Error en la consulta", 
                    "data" => $e->getMessage()
                );
            }

            return response()
                ->json($response, $restResponse)
                ->header("Access-Control-Allow-Origin", "*");
        }
    }

    public function getEjercicio( Request $r ) {
        if ( Request()->header('x-glowme-key') != $_ENV['X_GLOWME_API'] ) { 
            return response()
            ->json([ 
                'error' => true, 
                'message' => "Api key error", 
                'data' => "Acceso no permitido" 
            ], 403)
            ->header("Access-Control-Allow-Origin", "*");
        } else {
            try {
            	$TrackingExercise = TrackingExercise::select( "done", "date_at", DB::Raw( "Date(date_at) as fecha" ) )
                ->where("i_client", $r->cliente)
                ->orderBy("date_at")
                ->groupBy("fecha")
                ->get();

                $resultPeso = array();
                foreach ( $TrackingExercise as $item ) {
                	$resultPeso[] = array(
                		"date" => date("d-m-Y", strtotime($item['date_at'])), 
                		"ejercicio" => $item['done']
                	);
                }

                $restResponse = 200;
                $response = array(
                    "error" => false,
                    "message" => "Consulta exitosa", 
                    "data" => $resultPeso
                );
            } catch (QueryException $e) {
                $restResponse = 500;
                $response = array(
                    "error" => true,
                    "message" => "Error en la consulta", 
                    "data" => $e->getMessage()
                );
            }

            return response()
                ->json($response, $restResponse)
                ->header("Access-Control-Allow-Origin", "*");
        }
    }

    public function getNutricion( Request $r ) {
        if ( Request()->header('x-glowme-key') != $_ENV['X_GLOWME_API'] ) { 
            return response()
            ->json([ 
                'error' => true, 
                'message' => "Api key error", 
                'data' => "Acceso no permitido" 
            ], 403)
            ->header("Access-Control-Allow-Origin", "*");
        } else {
            try {
                $TrackingNutrition = TrackingNutrition::select( "done", "date_at", DB::Raw( "Date(date_at) as fecha" ) )->where("i_client", $r->cliente)->orderBy("date_at")->groupBy("fecha")->get();

                $resultNutricion = array();
                foreach ( $TrackingNutrition as $item ) {
                    $resultNutricion[] = array(
                        "date" => date("d-m-Y", strtotime($item['date_at'])), 
                        "nutricon" => $item['done']
                    );
                }

                $restResponse = 200;
                $response = array(
                    "error" => false,
                    "message" => "Consulta exitosa", 
                    "data" => $resultNutricion
                );
            } catch (QueryException $e) {
                $restResponse = 500;
                $response = array(
                    "error" => true,
                    "message" => "Error en la consulta", 
                    "data" => $e->getMessage()
                );
            }

            return response()
                ->json($response, $restResponse)
                ->header("Access-Control-Allow-Origin", "*");
        }
    }

    public function getSueno( Request $r ) {
        if ( Request()->header('x-glowme-key') != $_ENV['X_GLOWME_API'] ) { 
            return response()
            ->json([ 
                'error' => true, 
                'message' => "Api key error", 
                'data' => "Acceso no permitido" 
            ], 403)
            ->header("Access-Control-Allow-Origin", "*");
        } else {
            try {
                $TrackingSleep = TrackingSleep::select( 
                    DB::Raw("SUM(hours) as hours"), 
                    DB::Raw("SUM(minutes) as minutes"), 
                    DB::Raw("DATE(date_at) as date_at") 
                )
                ->where("i_client", $r->cliente)
                ->groupBy("date_at")
                ->orderBy("date_at")
                ->get()
                ->toArray();

                $resultSueno = array();
                foreach ( $TrackingSleep as $item ) {
                    
                    $resultSueno[] = array(
                        "date" => date("d-m-Y", strtotime($item['date_at'])), 
                        "horas" => $item['hours'] + floor($item['minutes'] / 60),
                        "minutos" => $item['minutes'] % 60,
                    );
                }

                $restResponse = 200;
                $response = array(
                    "error" => false,
                    "message" => "Consulta exitosa", 
                    "data" => $resultSueno
                );
            } catch (QueryException $e) {
                $restResponse = 500;
                $response = array(
                    "error" => true,
                    "message" => "Error en la consulta", 
                    "data" => $e->getMessage()
                );
            }

            return response()
                ->json($response, $restResponse)
                ->header("Access-Control-Allow-Origin", "*");
        }
    }

    public function getAnimo( Request $r ) {
        if ( Request()->header('x-glowme-key') != $_ENV['X_GLOWME_API'] ) { 
            return response()
            ->json([ 
                'error' => true, 
                'message' => "Api key error", 
                'data' => "Acceso no permitido" 
            ], 403)
            ->header("Access-Control-Allow-Origin", "*");
        } else {
            try {
                $TrackingMood = TrackingMood::select( "id", "i_mood", "date_at", DB::Raw( "Date(date_at) as fecha" ) )
                ->where("i_client", $r->cliente)
                ->orderBy("date_at")
                ->groupBy("fecha")
                ->get()
                ->toArray();

                $resultMood = array();
                foreach ( $TrackingMood as $item ) {
                    $CatMood = CatMood::select("name")->where("id", $item["i_mood"])->first();

                    $resultMood[] = array(
                        "id" => $item['id'],
                        "date" => date("d-m-Y", strtotime($item['date_at'])), 
                        "mood" => $CatMood['name'],
                        "i_mood" => $item['i_mood']
                    );
                }

                $restResponse = 200;
                $response = array(
                    "error" => false,
                    "message" => "Consulta exitosa", 
                    "data" => $resultMood
                );
            } catch (QueryException $e) {
                $restResponse = 500;
                $response = array(
                    "error" => true,
                    "message" => "Error en la consulta", 
                    "data" => $e->getMessage()
                );
            }

            return response()
                ->json($response, $restResponse)
                ->header("Access-Control-Allow-Origin", "*");
        } 
    }

    public function getEnergia( Request $r ) {
        if ( Request()->header('x-glowme-key') != $_ENV['X_GLOWME_API'] ) { 
            return response()
            ->json([ 
                'error' => true, 
                'message' => "Api key error", 
                'data' => "Acceso no permitido" 
            ], 403)
            ->header("Access-Control-Allow-Origin", "*");
        } else {
            try {
                $TrackingEnergy = TrackingEnergy::select( "name", "date_at", DB::Raw( "Date(date_at) as fecha" ) )
                ->where("i_client", $r->cliente)
                ->orderBy("date_at")
                ->groupBy("fecha")
                ->get()
                ->toArray();

                $resultMood = array();
                foreach ( $TrackingEnergy as $item ) {
                    $resultMood[] = array(
                        "date" => date("d-m-Y", strtotime($item['date_at'])), 
                        "energia" => $item['name']
                    );
                }

                $restResponse = 200;
                $response = array(
                    "error" => false,
                    "message" => "Consulta exitosa", 
                    "data" => $resultMood
                );
            } catch (QueryException $e) {
                $restResponse = 500;
                $response = array(
                    "error" => true,
                    "message" => "Error en la consulta", 
                    "data" => $e->getMessage()
                );
            }

            return response()
                ->json($response, $restResponse)
                ->header("Access-Control-Allow-Origin", "*");
        }
    }

    public function getSuplementos( Request $r ) {
        if ( Request()->header('x-glowme-key') != $_ENV['X_GLOWME_API'] ) { 
            return response()
            ->json([ 
                'error' => true, 
                'message' => "Api key error", 
                'data' => "Acceso no permitido" 
            ], 403)
            ->header("Access-Control-Allow-Origin", "*");
        } else {
            try {
                $TrackingSupplements = TrackingSupplements::select( DB::Raw("GROUP_CONCAT(i_supplement) AS ids"), DB::Raw( "count(i_supplement) as cantidad" ), "date_at", DB::Raw( "Date(date_at) as fecha" ) )
                ->where("i_client", $r->cliente)
                ->orderBy("date_at")
                ->groupBy("fecha")
                ->get();

                $resultSupplement = array();
                foreach ( $TrackingSupplements as $item ) {
                    $resultSupplement[] = array(
                        "ids" => explode(",", $item['ids']), 
                        "cantidad_suplementos" => $item['cantidad'], 
                        "suplementos" => $item['date_at']
                    );
                }

                $restResponse = 200;
                $response = array(
                    "error" => false,
                    "message" => "Consulta exitosa", 
                    "data" => $resultSupplement
                );
            } catch (QueryException $e) {
                $restResponse = 500;
                $response = array(
                    "error" => true,
                    "message" => "Error en la consulta", 
                    "data" => $e->getMessage()
                );
            }

            return response()
                ->json($response, $restResponse)
                ->header("Access-Control-Allow-Origin", "*");
        }
    }

    public function getMeditacion( Request $r ) {
        if ( Request()->header('x-glowme-key') != $_ENV['X_GLOWME_API'] ) { 
            return response()
            ->json([ 
                'error' => true, 
                'message' => "Api key error", 
                'data' => "Acceso no permitido" 
            ], 403)
            ->header("Access-Control-Allow-Origin", "*");
        } else {
            try {
                $TrackingMeditation = TrackingMeditation::select( "done", "date_at", DB::Raw( "Date(date_at) as fecha" ) )->where("i_client", $r->cliente)->orderBy("date_at")->groupBy("fecha")->get();

                $resultMeditacion = array();
                foreach ( $TrackingMeditation as $item ) {
                    $resultMeditacion[] = array(
                        "date" => date("d-m-Y", strtotime($item['date_at'])), 
                        "ejercicio" => $item['done']
                    );
                }

                $restResponse = 200;
                $response = array(
                    "error" => false,
                    "message" => "Consulta exitosa", 
                    "data" => $resultMeditacion
                );
            } catch (QueryException $e) {
                $restResponse = 500;
                $response = array(
                    "error" => true,
                    "message" => "Error en la consulta", 
                    "data" => $e->getMessage()
                );
            }

            return response()
                ->json($response, $restResponse)
                ->header("Access-Control-Allow-Origin", "*");
        }
    }

    public function getCiclo ( Request $r ) {
        if ( Request()->header('x-glowme-key') != $_ENV['X_GLOWME_API'] ) { 
            return response()
            ->json([ 
                'error' => true, 
                'message' => "Api key error", 
                'data' => "Acceso no permitido" 
            ], 403)
            ->header("Access-Control-Allow-Origin", "*");
        } else {
            try {
                $TrackingMenstrualCycle = TrackingMenstrualCycle::select( "id", "date_at", "days" )->where("i_client", $r->cliente)
                ->orderBy("date_at")
                ->get();

                $inicio = 0;
                $arrayGraph = array();
                foreach ( $TrackingMenstrualCycle as $key => $item ) {
                    if ( $key == 0 ) {
                        $inicio = date("Y-m-d", strtotime($item['date_at']));
                    } else {
                        $date1 = new DateTime($inicio);
                        $date2 = new DateTime(date("Y-m-d", strtotime($item['date_at'] . " - 1 DAY")));
                        $diff = $date1->diff($date2);
                        array_push($arrayGraph, array(
                            "id" => $item['id'], 
                            "date_at" => $item['date_at'], 
                            "days" => $diff->days
                        ));
                        $inicio = date("Y-m-d", strtotime($item['date_at']));
                    }
                }

                $restResponse = 200;
                $response = array(
                    "error" => false,
                    "message" => "Consulta exitosa", 
                    "data" => $arrayGraph
                );
            } catch (QueryException $e) {
                $restResponse = 500;
                $response = array(
                    "error" => true,
                    "message" => "Error en la consulta", 
                    "data" => $e->getMessage()
                );
            }

            return response()
                ->json($response, $restResponse)
                ->header("Access-Control-Allow-Origin", "*");
        }
    }
}