<?php

namespace App\Http\Controllers\Api\Integraciones\Programas\Workouts;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Database\QueryException;
use App\Models\Workouts;
use App\Models\WorkoutsVideos;
use App\Models\Clients;
use App\Models\PlanSemanalControl;
use App\Models\GeneralData;

class WorkoutController extends Controller {
    public function index () {
        if ( Request()->header('x-glowme-key') != $_ENV['X_GLOWME_API'] ) { 
            return response()
            ->json([ 
                'error' => true, 
                'message' => "Api key error", 
                'data' => "Acceso no permitido" 
            ], 403)
            ->header("Access-Control-Allow-Origin", "*");
        } else {
            try {
                $Workout = Workouts::select( "id", "program", "duration", "coach", DB::Raw( "CONCAT('". $_ENV["URL_PATH"] . "', banner) as banner" ))->get();

                $restResponse = 200;
                $response = array(
                    "error" => false,
                    "message" => "Consulta exitosa", 
                    "data" => $Workout
                );
            } catch (QueryException $e) {
                $restResponse = 500;
                $response = array(
                    "error" => true,
                    "message" => "No se pudo encontrar información", 
                    "data" => $e->getMessage()
                );
            }

            return response()
                ->json($response, $restResponse)
                ->header("Access-Control-Allow-Origin", "*");
        }
    }

    public function getProgramWorkoutDetalle ( Request $r ) {
        if ( Request()->header('x-glowme-key') != $_ENV['X_GLOWME_API'] ) { 
            return response()
            ->json([ 
                'error' => true, 
                'message' => "Api key error", 
                'data' => "Acceso no permitido" 
            ], 403)
            ->header("Access-Control-Allow-Origin", "*");
        } else {
            try {
                $restResponse = 200;
                
                $Videos = WorkoutsVideos::select("id", "week", "title", "areas", "equip", "intensity", "preview", "duration")->where("i_workout", $r->id)
                ->orderBy("week")
                ->orderBy("id")
                ->get()
                ->toArray();

                if ( count($Videos) > 0 ) { 
                    $weeks = WorkoutsVideos::select("week")->where("i_workout", $r->id)
                    ->orderBy("week", "DESC")
                    ->first()
                    ->toArray();

                    $semana = array();
                    $sem = 0;
                    for ( $i = 0; $i <= $weeks["week"]; $i++ ) {
                        $class = 1;
                        foreach( $Videos as $item ) {    
                            if ( $i == $item["week"] ) {
                                $semana[$sem][] = array(
                                    "id" => $item["id"],
                                    "class" => "Clase {$class}",
                                    "title" => $item["title"], 
                                    "areas" => $item["areas"], 
                                    "equip" => $item["equip"], 
                                    "intensity" => $item["intensity"], 
                                    "preview" => $item["preview"], 
                                    "duration" => $item["duration"]
                                );
                                $class++;
                            } else {
                                $class = 1;
                            }
                        }
                        $sem++;
                    }

                    $response = array(
                        "error" => false,
                        "message" => "Consulta exitosa", 
                        "data" => $semana
                    );
                } else {
                    $response = array(
                        "error" => true,
                        "message" => "Este programa no contiene videos", 
                        "data" => []
                    );
                }
            } catch (QueryException $e) {
                $restResponse = 500;
                $response = array(
                    "error" => true,
                    "message" => "Error en la consulta", 
                    "data" => $e->getMessage()
                );
            }

            return response()
                ->json($response, $restResponse)
                ->header("Access-Control-Allow-Origin", "*");
        }
    }

    public function getProgramWorkout( Request $r ) {
        if ( Request()->header('x-glowme-key') != $_ENV['X_GLOWME_API'] ) { 
            return response()
            ->json([ 
                'error' => true, 
                'message' => "Api key error", 
                'data' => "Acceso no permitido" 
            ], 403)
            ->header("Access-Control-Allow-Origin", "*");
        } else {
            try {
                $restResponse = 200;
                
                $Workout = Workouts::where("id", $r->id)->first();

                $result = array ( 
                    "id" => $Workout["id"], 
                    "program" => $Workout["program"], 
                    "banner" => $_ENV["URL_PATH"] . $Workout["banner"], 
                    "coach" => $Workout["coach"], 
                    "coach_pic" => $_ENV["URL_PATH"] . $Workout["coach_pic"], 
                    "duration_program" => $Workout["duration"], 
                    "class_week" => $Workout["by_week"], 
                    "duration_class" => $Workout["class_time"]
                );

                $Videos = WorkoutsVideos::select("id", "week", "title", "areas", "equip", "intensity", "preview", "duration")->where("i_workout", $Workout["id"])
                ->orderBy("week")
                ->orderBy("id")
                ->get()
                ->toArray();

                $weeks = WorkoutsVideos::select("week")->where("i_workout", $r->id)
                ->orderBy("week", "DESC")
                ->first();

                if ( $weeks == null ) {
                    $semana = [];
                } else {
                    $semana = array();
                    $sem = 0;
                    for ( $i = 0; $i <= $weeks["week"]; $i++ ) {
                        $class = 1;
                        foreach( $Videos as $item ) {    
                            if ( $i == $item["week"] ) {
                                $semana[$sem][] = array(
                                    "id" => $item["id"],
                                    "class" => "Clase {$class}",
                                    "title" => $item["title"], 
                                    "areas" => $item["areas"], 
                                    "equip" => $item["equip"], 
                                    "intensity" => $item["intensity"], 
                                    "preview" => $item["preview"], 
                                    "duration" => $item["duration"]
                                );
                                $class++;
                            } else {
                                $class = 1;
                            }
                        }
                        $sem++;
                    }
                }

                $response = array(
                    "error" => false,
                    "message" => "Consulta exitosa", 
                    "data" => [ "workout" => $result, "semana" => $semana ]
                );
            } catch (QueryException $e) {
                $restResponse = 500;
                $response = array(
                    "error" => true,
                    "message" => "Error en la consulta", 
                    "data" => $e->getMessage()
                );
            }

            return response()
                ->json($response, $restResponse)
                ->header("Access-Control-Allow-Origin", "*");
        }
    }
    
    public function getWorkoutOnDemand() {
        if ( Request()->header('x-glowme-key') != $_ENV['X_GLOWME_API'] ) { 
            return response()
            ->json([ 
                'error' => true, 
                'message' => "Api key error", 
                'data' => "Acceso no permitido" 
            ], 403)
            ->header("Access-Control-Allow-Origin", "*");
        } else {
            try {
                $WorkoutsVideos = WorkoutsVideos::get()->toArray();
                
                $result = array();
                foreach ( $WorkoutsVideos as $item ){

                    $programa = Workouts::select("program")->where("id", $item['i_workout'])->first();

                    array_push($result, array(
                        "id" => $item["id"], 
                        "programa" => $programa["program"], 
                        "title" => $item["title"], 
                        "areas" => $item["areas"], 
                        "preview" => $item["preview"], 
                        "duration" => $item["duration"]
                    ));
                }

                $restResponse = 200;
                $response = array(
                    "error" => false,
                    "message" => "Consulta exitosa", 
                    "data" => $result
                );
            } catch (QueryException $e) {
                $restResponse = 500;
                $response = array(
                    "error" => true,
                    "message" => "Error en la consulta", 
                    "data" => $e->getMessage()
                );
            }

            return response()
                ->json($response, $restResponse)
                ->header("Access-Control-Allow-Origin", "*");
        }
    }

    public function getWorkoutVideo ( Request $r ) {
        if ( Request()->header('x-glowme-key') != $_ENV['X_GLOWME_API'] ) { 
            return response()
            ->json([ 
                'error' => true, 
                'message' => "Api key error", 
                'data' => "Acceso no permitido" 
            ], 403)
            ->header("Access-Control-Allow-Origin", "*");
        } else {
            try {
                $WorkoutsVideos = WorkoutsVideos::where("id", $r->id)->first();
                
                if ( $WorkoutsVideos != null ){
                    preg_match("/\d+/", $WorkoutsVideos->vimeo, $idVimeo, PREG_OFFSET_CAPTURE, 0);

                    $headers = array(
                        'Content-Type:application/json',
                        'Authorization: Bearer '. $_ENV['VIMEO_TOKEN']
                    );

                    $curl = curl_init( $_ENV['VIMEO_URL'] . "/" . $idVimeo[0][0] );
                    curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);
                    curl_setopt($curl, CURLOPT_TIMEOUT, 30);
                    curl_setopt($curl, CURLOPT_FOLLOWLOCATION, 1);
                    curl_setopt($curl, CURLOPT_HTTPHEADER, $headers);
                    $return = curl_exec($curl);
                    curl_close($curl);
                    $arrayResponse = json_decode($return, true);

                    $linkWeb = "";
                    foreach ($arrayResponse['play']['progressive'] as $item ) {
                        if( $item['width'] == 1920 ) {
                            $linkWeb = $item['link'];
                        }
                    }
                
                    $programa = Workouts::select("program", "coach")->where("id", $WorkoutsVideos['i_workout'])->first();

                    $seachClase = WorkoutsVideos::select("id")->where("i_workout", $WorkoutsVideos["i_workout"])->get()->toArray();
                    
                    $clase = 1;
                    foreach( $seachClase as $item ) {
                        if ( $item["id"] == $r->id ) {
                            break;
                        } else {
                            $clase++;
                        }
                    }

                    $result = array(
                        "program" => $programa["program"],
                        "clase" => "Clase " . $clase,
                        "coach" => $programa["coach"],
                        "title" => $WorkoutsVideos["title"],
                        "areas" => $WorkoutsVideos["areas"],
                        "equip" => $WorkoutsVideos["equip"],
                        "intensity" => $WorkoutsVideos["intensity"],
                        "video" => $WorkoutsVideos["vimeo"],
                        "duration" => $WorkoutsVideos["duration"], 
                        "videoWeb" => $linkWeb, 
                        "videoMobile" => $WorkoutsVideos["videoMobile"]
                    );

                    WorkoutsVideos::where("id", $r->id)->update(["vimeo" => $idVimeo[0][0]]);

                    $restResponse = 200;
                    $response = array(
                        "error" => false,
                        "message" => "Consulta exitosa", 
                        "data" => $result
                    );
                } else {
                    $restResponse = 500;
                    $response = array(
                        "error" => true,
                        "message" => "El video solicitado no existe", 
                        "data" => []
                    );
                }
            } catch (QueryException $e) {
                $restResponse = 500;
                $response = array(
                    "error" => true,
                    "message" => "Error en la consulta", 
                    "data" => $e->getMessage()
                );
            }

            return response()
                ->json($response, $restResponse)
                ->header("Access-Control-Allow-Origin", "*");
        }
    }

    public function putPlan( Request $r ) {
        if ( Request()->header('x-glowme-key') != $_ENV['X_GLOWME_API'] ) { 
            return response()
            ->json([ 
                'error' => true, 
                'message' => "Api key error", 
                'data' => "Acceso no permitido" 
            ], 403)
            ->header("Access-Control-Allow-Origin", "*");
        } else {
            try {
                $cliente = Clients::where("id", $r->cliente)->update(["workout_plan" => $r->plan]);

                $workouts = Workouts::select("program", "coach")->where("id", $r->plan)->first();

                $json = PlanSemanalControl::select("json")->where("i_client", $r->cliente)->first();

                $result = json_decode( $json['json'], true );
                $result['plan_workout'] = $workouts['program'];
                $result['coach'] = $workouts['coach'];

                $workoutItems = null;
                if ( $workouts ) {
                    $workoutItems = array();
                    for ( $i = 0; $i < 25; $i++ ) {
                        $workoutPos = GeneralData::select("workout_position")->where("i_client", $r->cliente)->first();

                        $workoutVid = WorkoutsVideos::select("id", "title", "areas", "equip", "preview", "duration")
                        ->where("i_workout", $r->plan)
                        ->where("id", ">=", $workoutPos['workout_position'])
                        ->get()
                        ->toArray();

                        if( count($workoutVid) > 0 ) {
                            $data = array(
                                "id" => $workoutVid[0]['id'],
                                "clase" => "Clase " . $i+1,
                                "title" => $workoutVid[0]['title'],
                                "areas" => $workoutVid[0]['areas'],
                                "equip" => $workoutVid[0]['equip'],
                                "preview" => $workoutVid[0]['preview'],
                                "duration" => $workoutVid[0]['duration']
                            );
                        } else {
                            $data = array(
                                "id" => 0,
                                "clase" => "",
                                "title" => "",
                                "areas" => "",
                                "equip" => "",
                                "preview" => "",
                                "duration" => 0
                            );
                        }

                        array_push($workoutItems, $data);

                        if ( isset($workoutVid[1]['id']) ) {
                            GeneralData::where("i_client", $r->cliente)->update(["workout_position" => $workoutVid[1]['id']]);
                        } else {
                            $workoutVid = WorkoutsVideos::select("id")->where("i_workout", $r->plan)->first();
                            if ( $workoutVid != null ){
                                GeneralData::where("i_client", $r->cliente)->update(["workout_position" => $workoutVid['id']]);
                            }
                        }
                    }
                }

                // Semana 1
                $result[0]['dias'][0]['workout']['id'] = $workoutItems[0]['id'];
                $result[0]['dias'][0]['workout']['clase'] = $workoutItems[0]['clase'];
                $result[0]['dias'][0]['workout']['nombre'] = $workoutItems[0]['title'];
                $result[0]['dias'][0]['workout']['tiempo'] = $workoutItems[0]['duration'];
                $result[0]['dias'][0]['workout']['area'] = $workoutItems[0]['areas'];
                $result[0]['dias'][0]['workout']['equipo'] = $workoutItems[0]['equip'];
                $result[0]['dias'][0]['workout']['preview'] = $workoutItems[0]['preview'];

                $result[0]['dias'][1]['workout']['id'] = $workoutItems[1]['id'];
                $result[0]['dias'][1]['workout']['clase'] = $workoutItems[1]['clase'];
                $result[0]['dias'][1]['workout']['nombre'] = $workoutItems[1]['title'];
                $result[0]['dias'][1]['workout']['tiempo'] = $workoutItems[1]['duration'];
                $result[0]['dias'][1]['workout']['area'] = $workoutItems[1]['areas'];
                $result[0]['dias'][1]['workout']['equipo'] = $workoutItems[1]['equip'];
                $result[0]['dias'][1]['workout']['preview'] = $workoutItems[1]['preview'];

                $result[0]['dias'][2]['workout']['id'] = $workoutItems[2]['id'];
                $result[0]['dias'][2]['workout']['clase'] = $workoutItems[2]['clase'];
                $result[0]['dias'][2]['workout']['nombre'] = $workoutItems[2]['title'];
                $result[0]['dias'][2]['workout']['tiempo'] = $workoutItems[2]['duration'];
                $result[0]['dias'][2]['workout']['area'] = $workoutItems[2]['areas'];
                $result[0]['dias'][2]['workout']['equipo'] = $workoutItems[2]['equip'];
                $result[0]['dias'][2]['workout']['preview'] = $workoutItems[2]['preview'];

                $result[0]['dias'][3]['workout']['id'] = $workoutItems[3]['id'];
                $result[0]['dias'][3]['workout']['clase'] = $workoutItems[3]['clase'];
                $result[0]['dias'][3]['workout']['nombre'] = $workoutItems[3]['title'];
                $result[0]['dias'][3]['workout']['tiempo'] = $workoutItems[3]['duration'];
                $result[0]['dias'][3]['workout']['area'] = $workoutItems[3]['areas'];
                $result[0]['dias'][3]['workout']['equipo'] = $workoutItems[3]['equip'];
                $result[0]['dias'][3]['workout']['preview'] = $workoutItems[3]['preview'];

                $result[0]['dias'][4]['workout']['id'] = $workoutItems[4]['id'];
                $result[0]['dias'][4]['workout']['clase'] = $workoutItems[4]['clase'];
                $result[0]['dias'][4]['workout']['nombre'] = $workoutItems[4]['title'];
                $result[0]['dias'][4]['workout']['tiempo'] = $workoutItems[4]['duration'];
                $result[0]['dias'][4]['workout']['area'] = $workoutItems[4]['areas'];
                $result[0]['dias'][4]['workout']['equipo'] = $workoutItems[4]['equip'];
                $result[0]['dias'][4]['workout']['preview'] = $workoutItems[4]['preview'];

                // Semana 2
                $result[1]['dias'][0]['workout']['id'] = $workoutItems[5]['id'];
                $result[1]['dias'][0]['workout']['clase'] = $workoutItems[5]['clase'];
                $result[1]['dias'][0]['workout']['nombre'] = $workoutItems[5]['title'];
                $result[1]['dias'][0]['workout']['tiempo'] = $workoutItems[5]['duration'];
                $result[1]['dias'][0]['workout']['area'] = $workoutItems[5]['areas'];
                $result[1]['dias'][0]['workout']['equipo'] = $workoutItems[5]['equip'];
                $result[1]['dias'][0]['workout']['preview'] = $workoutItems[5]['preview'];

                $result[1]['dias'][1]['workout']['id'] = $workoutItems[6]['id'];
                $result[1]['dias'][1]['workout']['clase'] = $workoutItems[6]['clase'];
                $result[1]['dias'][1]['workout']['nombre'] = $workoutItems[6]['title'];
                $result[1]['dias'][1]['workout']['tiempo'] = $workoutItems[6]['duration'];
                $result[1]['dias'][1]['workout']['area'] = $workoutItems[6]['areas'];
                $result[1]['dias'][1]['workout']['equipo'] = $workoutItems[6]['equip'];
                $result[1]['dias'][1]['workout']['preview'] = $workoutItems[6]['preview'];

                $result[1]['dias'][2]['workout']['id'] = $workoutItems[7]['id'];
                $result[1]['dias'][2]['workout']['clase'] = $workoutItems[7]['clase'];
                $result[1]['dias'][2]['workout']['nombre'] = $workoutItems[7]['title'];
                $result[1]['dias'][2]['workout']['tiempo'] = $workoutItems[7]['duration'];
                $result[1]['dias'][2]['workout']['area'] = $workoutItems[7]['areas'];
                $result[1]['dias'][2]['workout']['equipo'] = $workoutItems[7]['equip'];
                $result[1]['dias'][2]['workout']['preview'] = $workoutItems[7]['preview'];

                $result[1]['dias'][3]['workout']['id'] = $workoutItems[8]['id'];
                $result[1]['dias'][3]['workout']['clase'] = $workoutItems[8]['clase'];
                $result[1]['dias'][3]['workout']['nombre'] = $workoutItems[8]['title'];
                $result[1]['dias'][3]['workout']['tiempo'] = $workoutItems[8]['duration'];
                $result[1]['dias'][3]['workout']['area'] = $workoutItems[8]['areas'];
                $result[1]['dias'][3]['workout']['equipo'] = $workoutItems[8]['equip'];
                $result[1]['dias'][3]['workout']['preview'] = $workoutItems[8]['preview'];

                $result[1]['dias'][4]['workout']['id'] = $workoutItems[9]['id'];
                $result[1]['dias'][4]['workout']['clase'] = $workoutItems[9]['clase'];
                $result[1]['dias'][4]['workout']['nombre'] = $workoutItems[9]['title'];
                $result[1]['dias'][4]['workout']['tiempo'] = $workoutItems[9]['duration'];
                $result[1]['dias'][4]['workout']['area'] = $workoutItems[9]['areas'];
                $result[1]['dias'][4]['workout']['equipo'] = $workoutItems[9]['equip'];
                $result[1]['dias'][4]['workout']['preview'] = $workoutItems[9]['preview'];

                // Semana 3
                $result[2]['dias'][0]['workout']['id'] = $workoutItems[10]['id'];
                $result[2]['dias'][0]['workout']['clase'] = $workoutItems[10]['clase'];
                $result[2]['dias'][0]['workout']['nombre'] = $workoutItems[10]['title'];
                $result[2]['dias'][0]['workout']['tiempo'] = $workoutItems[10]['duration'];
                $result[2]['dias'][0]['workout']['area'] = $workoutItems[10]['areas'];
                $result[2]['dias'][0]['workout']['equipo'] = $workoutItems[10]['equip'];
                $result[2]['dias'][0]['workout']['preview'] = $workoutItems[10]['preview'];

                $result[2]['dias'][1]['workout']['id'] = $workoutItems[11]['id'];
                $result[2]['dias'][1]['workout']['clase'] = $workoutItems[11]['clase'];
                $result[2]['dias'][1]['workout']['nombre'] = $workoutItems[11]['title'];
                $result[2]['dias'][1]['workout']['tiempo'] = $workoutItems[11]['duration'];
                $result[2]['dias'][1]['workout']['area'] = $workoutItems[11]['areas'];
                $result[2]['dias'][1]['workout']['equipo'] = $workoutItems[11]['equip'];
                $result[2]['dias'][1]['workout']['preview'] = $workoutItems[11]['preview'];

                $result[2]['dias'][2]['workout']['id'] = $workoutItems[12]['id'];
                $result[2]['dias'][2]['workout']['clase'] = $workoutItems[12]['clase'];
                $result[2]['dias'][2]['workout']['nombre'] = $workoutItems[12]['title'];
                $result[2]['dias'][2]['workout']['tiempo'] = $workoutItems[12]['duration'];
                $result[2]['dias'][2]['workout']['area'] = $workoutItems[12]['areas'];
                $result[2]['dias'][2]['workout']['equipo'] = $workoutItems[12]['equip'];
                $result[2]['dias'][2]['workout']['preview'] = $workoutItems[12]['preview'];

                $result[2]['dias'][3]['workout']['id'] = $workoutItems[13]['id'];
                $result[2]['dias'][3]['workout']['clase'] = $workoutItems[13]['clase'];
                $result[2]['dias'][3]['workout']['nombre'] = $workoutItems[13]['title'];
                $result[2]['dias'][3]['workout']['tiempo'] = $workoutItems[13]['duration'];
                $result[2]['dias'][3]['workout']['area'] = $workoutItems[13]['areas'];
                $result[2]['dias'][3]['workout']['equipo'] = $workoutItems[13]['equip'];
                $result[2]['dias'][3]['workout']['preview'] = $workoutItems[13]['preview'];

                $result[2]['dias'][4]['workout']['id'] = $workoutItems[14]['id'];
                $result[2]['dias'][4]['workout']['clase'] = $workoutItems[14]['clase'];
                $result[2]['dias'][4]['workout']['nombre'] = $workoutItems[14]['title'];
                $result[2]['dias'][4]['workout']['tiempo'] = $workoutItems[14]['duration'];
                $result[2]['dias'][4]['workout']['area'] = $workoutItems[14]['areas'];
                $result[2]['dias'][4]['workout']['equipo'] = $workoutItems[14]['equip'];
                $result[2]['dias'][4]['workout']['preview'] = $workoutItems[14]['preview'];

                // Semana 4
                $result[3]['dias'][0]['workout']['id'] = $workoutItems[15]['id'];
                $result[3]['dias'][0]['workout']['clase'] = $workoutItems[15]['clase'];
                $result[3]['dias'][0]['workout']['nombre'] = $workoutItems[15]['title'];
                $result[3]['dias'][0]['workout']['tiempo'] = $workoutItems[15]['duration'];
                $result[3]['dias'][0]['workout']['area'] = $workoutItems[15]['areas'];
                $result[3]['dias'][0]['workout']['equipo'] = $workoutItems[15]['equip'];
                $result[3]['dias'][0]['workout']['preview'] = $workoutItems[15]['preview'];

                $result[3]['dias'][1]['workout']['id'] = $workoutItems[16]['id'];
                $result[3]['dias'][1]['workout']['clase'] = $workoutItems[16]['clase'];
                $result[3]['dias'][1]['workout']['nombre'] = $workoutItems[16]['title'];
                $result[3]['dias'][1]['workout']['tiempo'] = $workoutItems[16]['duration'];
                $result[3]['dias'][1]['workout']['area'] = $workoutItems[16]['areas'];
                $result[3]['dias'][1]['workout']['equipo'] = $workoutItems[16]['equip'];
                $result[3]['dias'][1]['workout']['preview'] = $workoutItems[16]['preview'];

                $result[3]['dias'][2]['workout']['id'] = $workoutItems[17]['id'];
                $result[3]['dias'][2]['workout']['clase'] = $workoutItems[17]['clase'];
                $result[3]['dias'][2]['workout']['nombre'] = $workoutItems[17]['title'];
                $result[3]['dias'][2]['workout']['tiempo'] = $workoutItems[17]['duration'];
                $result[3]['dias'][2]['workout']['area'] = $workoutItems[17]['areas'];
                $result[3]['dias'][2]['workout']['equipo'] = $workoutItems[17]['equip'];
                $result[3]['dias'][2]['workout']['preview'] = $workoutItems[17]['preview'];

                $result[3]['dias'][3]['workout']['id'] = $workoutItems[18]['id'];
                $result[3]['dias'][3]['workout']['clase'] = $workoutItems[18]['clase'];
                $result[3]['dias'][3]['workout']['nombre'] = $workoutItems[18]['title'];
                $result[3]['dias'][3]['workout']['tiempo'] = $workoutItems[18]['duration'];
                $result[3]['dias'][3]['workout']['area'] = $workoutItems[18]['areas'];
                $result[3]['dias'][3]['workout']['equipo'] = $workoutItems[18]['equip'];
                $result[3]['dias'][3]['workout']['preview'] = $workoutItems[18]['preview'];

                $result[3]['dias'][4]['workout']['id'] = $workoutItems[19]['id'];
                $result[3]['dias'][4]['workout']['clase'] = $workoutItems[19]['clase'];
                $result[3]['dias'][4]['workout']['nombre'] = $workoutItems[19]['title'];
                $result[3]['dias'][4]['workout']['tiempo'] = $workoutItems[19]['duration'];
                $result[3]['dias'][4]['workout']['area'] = $workoutItems[19]['areas'];
                $result[3]['dias'][4]['workout']['equipo'] = $workoutItems[19]['equip'];
                $result[3]['dias'][4]['workout']['preview'] = $workoutItems[19]['preview'];

                // Semana 5
                $result[4]['dias'][0]['workout']['id'] = $workoutItems[20]['id'];
                $result[4]['dias'][0]['workout']['clase'] = $workoutItems[20]['clase'];
                $result[4]['dias'][0]['workout']['nombre'] = $workoutItems[20]['title'];
                $result[4]['dias'][0]['workout']['tiempo'] = $workoutItems[20]['duration'];
                $result[4]['dias'][0]['workout']['area'] = $workoutItems[20]['areas'];
                $result[4]['dias'][0]['workout']['equipo'] = $workoutItems[20]['equip'];
                $result[4]['dias'][0]['workout']['preview'] = $workoutItems[20]['preview'];

                $result[4]['dias'][1]['workout']['id'] = $workoutItems[21]['id'];
                $result[4]['dias'][1]['workout']['clase'] = $workoutItems[21]['clase'];
                $result[4]['dias'][1]['workout']['nombre'] = $workoutItems[21]['title'];
                $result[4]['dias'][1]['workout']['tiempo'] = $workoutItems[21]['duration'];
                $result[4]['dias'][1]['workout']['area'] = $workoutItems[21]['areas'];
                $result[4]['dias'][1]['workout']['equipo'] = $workoutItems[21]['equip'];
                $result[4]['dias'][1]['workout']['preview'] = $workoutItems[21]['preview'];

                $result[4]['dias'][2]['workout']['id'] = $workoutItems[22]['id'];
                $result[4]['dias'][2]['workout']['clase'] = $workoutItems[22]['clase'];
                $result[4]['dias'][2]['workout']['nombre'] = $workoutItems[22]['title'];
                $result[4]['dias'][2]['workout']['tiempo'] = $workoutItems[22]['duration'];
                $result[4]['dias'][2]['workout']['area'] = $workoutItems[22]['areas'];
                $result[4]['dias'][2]['workout']['equipo'] = $workoutItems[22]['equip'];
                $result[4]['dias'][2]['workout']['preview'] = $workoutItems[22]['preview'];

                $result[4]['dias'][3]['workout']['id'] = $workoutItems[23]['id'];
                $result[4]['dias'][3]['workout']['clase'] = $workoutItems[23]['clase'];
                $result[4]['dias'][3]['workout']['nombre'] = $workoutItems[23]['title'];
                $result[4]['dias'][3]['workout']['tiempo'] = $workoutItems[23]['duration'];
                $result[4]['dias'][3]['workout']['area'] = $workoutItems[23]['areas'];
                $result[4]['dias'][3]['workout']['equipo'] = $workoutItems[23]['equip'];
                $result[4]['dias'][3]['workout']['preview'] = $workoutItems[23]['preview'];

                $result[4]['dias'][4]['workout']['id'] = $workoutItems[24]['id'];
                $result[4]['dias'][4]['workout']['clase'] = $workoutItems[24]['clase'];
                $result[4]['dias'][4]['workout']['nombre'] = $workoutItems[24]['title'];
                $result[4]['dias'][4]['workout']['tiempo'] = $workoutItems[24]['duration'];
                $result[4]['dias'][4]['workout']['area'] = $workoutItems[24]['areas'];
                $result[4]['dias'][4]['workout']['equipo'] = $workoutItems[24]['equip'];
                $result[4]['dias'][4]['workout']['preview'] = $workoutItems[24]['preview'];

                PlanSemanalControl::where("i_client", $r->cliente)->update(['json' => json_encode($result)]);                

                $restResponse = 200;
                $response = array(
                    "error" => false,
                    "message" => "Consulta exitosa", 
                    "data" => []
                );
            } catch (QueryException $e) {
                $restResponse = 500;
                $response = array(
                    "error" => true,
                    "message" => "Error en la consulta", 
                    "data" => $e->getMessage()
                );
            }

            return response()
                ->json($response, $restResponse)
                ->header("Access-Control-Allow-Origin", "*");
        }
    }
}