<?php

namespace App\Http\Controllers\Api\Integraciones\Stripe;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Database\QueryException;
use App\Models\Clients;
use App\Models\GeneralData;
use App\Models\Suscriptions;

class StripeController extends Controller {
    public function crearStripeCustomer ( Request $r ) {
        if ( Request()->header('x-glowme-key') != $_ENV['X_GLOWME_API'] ) { 
            return response()
            ->json([ 
                'error' => true, 
                'message' => "Api key error", 
                'data' => "Acceso no permitido" 
            ], 403)
            ->header("Access-Control-Allow-Origin", "*");
        } else {
            try {
                $restResponse = 200;

                $clientes = Clients::select("fullname", "email", "phone")->where("id", $r->client)->first();

                $stripe = new \Stripe\StripeClient($_ENV['STRIPE_SECRET']);

                $createReponse = $stripe->customers->create([
                    'email' => trim($clientes['email']),
                    'name' => trim($clientes['fullname']),
                    'phone' => "52".trim($clientes['phone'])
                ]);

                Clients::where("id", $r->client)->update([ 'stripe_source' => $createReponse->id ]);

                $response = array(
                    "error" => false,
                    "message" => "Consulta exitosa", 
                    "data" => ["stripe_cource" => $createReponse->id]
                );
            } catch (QueryException $e) {
                $restResponse = 500;
                $response = array(
                    "error" => true,
                    "message" => "No se pudo encontrar información", 
                    "data" => $e->getMessage()
                );
            }

            return response()
                ->json($response, $restResponse)
                ->header("Access-Control-Allow-Origin", "*");
        }
    }

    public function setStripePayment( Request $r ) {
        if ( Request()->header('x-glowme-key') != $_ENV['X_GLOWME_API'] ) { 
            return response()
            ->json([ 
                'error' => true, 
                'message' => "Api key error", 
                'data' => "Acceso no permitido" 
            ], 403)
            ->header("Access-Control-Allow-Origin", "*");
        } else {
            try {
                $restResponse = 200;

                $clientes = Clients::select("stripe_source")->where("id", $r->client)->first();

                $stripe = new \Stripe\StripeClient($_ENV['STRIPE_SECRET']);

                try {
                    $createReponsePayment = $stripe->paymentMethods->attach(
                        $r->payment,
                        [ 'customer' => $clientes['stripe_source'] ]
                    );

                    $createReponsePaymentDefault = $stripe->customers->update(
                      $clientes['stripe_source'],
                      ['invoice_settings' => ['default_payment_method' => $createReponsePayment->id]]
                    );

                    $response = array(
                        "error" => false,
                        "message" => "Consulta exitosa", 
                        "data" => []
                    );
                } catch ( \Stripe\Exception\CardException $stripeError ) {
                    $response = array(
                        "error" => true,
                        "message" => $stripeError->getError()->message, 
                        "data" => []
                    );
                }
                

                
            } catch (QueryException $e) {
                $restResponse = 500;
                $response = array(
                    "error" => true,
                    "message" => "No se pudo encontrar información", 
                    "data" => $e->getMessage()
                );
            }

            return response()
                ->json($response, $restResponse)
                ->header("Access-Control-Allow-Origin", "*");
        }
    }

    public function customerSubscribe( Request $r ) {
        if ( Request()->header('x-glowme-key') != $_ENV['X_GLOWME_API'] ) { 
            return response()
            ->json([ 
                'error' => true, 
                'message' => "Api key error", 
                'data' => "Acceso no permitido" 
            ], 403)
            ->header("Access-Control-Allow-Origin", "*");
        } else {
            try {
                $restResponse = 200;

                $clientes = Clients::select("stripe_source", 'suscription_plan')->where("id", $r->client)->first();

                $suscripcion = Suscriptions::select("stripe_price")->where("id", $clientes['suscription_plan'])->first();

                $stripe = new \Stripe\StripeClient($_ENV['STRIPE_SECRET']);
        
                $createReponse = $stripe->subscriptions->create([
                    'customer' => $clientes['stripe_source'],
                    'items' => [
                        ['price' => $suscripcion['stripe_price']],
                    ],
                    'cancel_at_period_end' => true
                ]);

                if ( $createReponse->id ) {
                    Clients::where("id", $r->client)->update(
                        [ 
                            "source_active" => "stripe", 
                            "suscription_id" => $createReponse->id,  
                            "suscription_at" => date("Y-m-d H:i:s"), 
                            "last_charge" => date("Y-m-d H:i:s"), 
                            "status" => 1, 
                            "suscription_cancel_at" => NULL
                        ]
                    );
                    $response = array(
                        "error" => false,
                        "message" => "Consulta exitosa", 
                        "data" => [ 'stripe_subscription' => $createReponse->id ]
                    );
                } else {
                    $response = array(
                        "error" => true,
                        "message" => "No pudo completarse la suscripción", 
                        "data" => []
                    );
                }

            } catch (QueryException $e) {
                $restResponse = 500;
                $response = array(
                    "error" => true,
                    "message" => "No se pudo encontrar información", 
                    "data" => $e->getMessage()
                );
            }

            return response()
                ->json($response, $restResponse)
                ->header("Access-Control-Allow-Origin", "*");
        }
    }
}
