<?php

namespace App\Http\Controllers\Api\Profiles;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Database\QueryException;
use App\Models\UserProfiles;
use App\Models\SystemModules;

class ProfilesController extends Controller {
    public function getProfiles() {
        $response = array(
            "error" => false,
            "message" => "Sin error"
        );

        try {
            $profiles = UserProfiles::select(
            		"id", 
            		"name", 
            		"permits"
            	)
            	->orderBy("id", "ASC")
            	->get();

            $response = array(
                "error" => true,
                "message" => "Sin error", 
                "data" => $profiles
            );
        } catch ( QueryException $e ) {
            $response = array(
                "error" => true,
                "message" => "Error en la consulta", 
                "data" => $e->getMessage()
            );
        }

        return response()
            ->json($response, 200)
            ->header("Access-Control-Allow-Origin", "*");
    }

    public function getProfileID($id) {
    	$response = array(
            "error" => false,
            "message" => "Sin error"
        );

        try {
            $uProf = UserProfiles::select(
        		"name",
        		"permits"
        	)
        	->where("id", $id)
        	->orderBy("id", "ASC")
        	->get();

			$response = array(
                "error" => false,
                "message" => "Sin error", 
                "data" => $uProf
            );

        } catch ( QueryException $e ) {
            $response = array(
                "error" => true,
                "message" => "Error en la consulta", 
                "data" => $e->getMessage()
            );
        }

        return response()
            ->json($response, 200)
            ->header("Access-Control-Allow-Origin", "*");
    }

    public function store(Request $r) {
        $response = array(
            "error" => false,
            "message" => "Sin error"
        );

        try {
            $sysModules = SystemModules::select(
        		DB::Raw("REPLACE(url,'/', '') as url")
        	)
        	->where("url", "!=", "/dashboard")
        	->where("url", "!=", "/cerrar-sesion")
        	->orderBy("id", "ASC")
        	->get();

        	$section = array();

        	foreach ( $sysModules as $item ) {
        		$permits = array( 
        			$r[$item['url']."Ver"] ? 1 : 0, 
        			$r[$item['url']."Crear"] ? 1 : 0, 
        			$r[$item['url']."Editar"] ? 1 : 0, 
        			$r[$item['url']."Eliminar"] ? 1 : 0
        		);
        		array_push($section, $permits);
        	}

        	$storeProfile = new UserProfiles();
        	$storeProfile->name = $r->perfil;
        	$storeProfile->permits = json_encode($section);

			if ( $storeProfile->save() ) {
	            $response = array(
	                "error" => false,
	                "message" => "Sin error", 
	                "data" => $section
	            );
	        } else {
	        	$response = array(
	                "error" => true,
	                "message" => "Error en la consulta", 
	                "data" => $e->getMessage()
	            );
	        }
        } catch ( QueryException $e ) {
            $response = array(
                "error" => true,
                "message" => "Error en la consulta", 
                "data" => $e->getMessage()
            );
        }

        return response()
            ->json($response, 200)
            ->header("Access-Control-Allow-Origin", "*");
    }

    public function update(Request $r) {
        $response = array(
            "error" => false,
            "message" => "Sin error"
        );

        try {
            $sysModules = SystemModules::select(
        		DB::Raw("REPLACE(url,'/', '') as url")
        	)
        	->where("url", "!=", "/dashboard")
        	->where("url", "!=", "/cerrar-sesion")
        	->orderBy("id", "ASC")
        	->get();

        	$section = array();

        	foreach ( $sysModules as $item ) {
        		$permits = array( 
        			$r[$item['url']."Ver"] ? 1 : 0, 
        			$r[$item['url']."Crear"] ? 1 : 0, 
        			$r[$item['url']."Editar"] ? 1 : 0, 
        			$r[$item['url']."Eliminar"] ? 1 : 0
        		);
        		array_push($section, $permits);
        	}

        	$updateProfile = UserProfiles::find($r->id);
        	$updateProfile->name = $r->perfil;
        	$updateProfile->permits = json_encode($section);

			if ( $updateProfile->save() ) {
	            $response = array(
	                "error" => false,
	                "message" => "Sin error", 
	                "data" => $section
	            );
	        } else {
	        	$response = array(
	                "error" => true,
	                "message" => "Error en la consulta", 
	                "data" => $e->getMessage()
	            );
	        }
        } catch ( QueryException $e ) {
            $response = array(
                "error" => true,
                "message" => "Error en la consulta", 
                "data" => $e->getMessage()
            );
        }

        return response()
            ->json($response, 200)
            ->header("Access-Control-Allow-Origin", "*");
    }

    public function delete(Request $r) {
        $response = array(
            "error" => false,
            "message" => "Sin error"
        );

        try {
        	$deleteProfile = UserProfiles::find($r->id);

			if ( $deleteProfile->delete() ) {
	            $response = array(
	                "error" => false,
	                "message" => "Sin error", 
	                "data" => $deleteProfile
	            );
	        } else {
	        	$response = array(
	                "error" => true,
	                "message" => "Error en la consulta", 
	                "data" => $e->getMessage()
	            );
	        }
        } catch ( QueryException $e ) {
            $response = array(
                "error" => true,
                "message" => "Error en la consulta", 
                "data" => $e->getMessage()
            );
        }

        return response()
            ->json($response, 200)
            ->header("Access-Control-Allow-Origin", "*");
    }
}
