<?php

namespace App\Http\Controllers\Api\Recipts;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Database\QueryException;
use App\Models\Recipts;
use App\Models\ProgramRecipts;
use App\Models\CalorieRecipts;
use App\Models\IngredientRecipts;
use App\Models\StepsRecipts;
use App\Models\KindFood;
use Illuminate\Support\Facades\File;

class ReciptsController extends Controller {
    public function getKindFood() {
        $response = array(
            "error" => false,
            "message" => "Sin error"
        );

        try {
            $kindFood = KindFood::select(
                "id", 
                "name"
            )
            ->orderBy("name")
            ->get();

            $response = array(
                "error" => true,
                "message" => "Sin error", 
                "data" => $kindFood
            );
        } catch ( QueryException $e ) {
            $response = array(
                "error" => true,
                "message" => "Error en la consulta", 
                "data" => $e->getMessage()
            );
        }

        return response()
            ->json($response, 200)
            ->header("Access-Control-Allow-Origin", "*");
    }

    public function getRecipts() {
        $response = array(
            "error" => false,
            "message" => "Sin error"
        );

        try {
            $recipts = DB::table('recipts')
            ->select(
                "recipts.id", 
                "recipts.name",
                "recipts.food_time", 
                "recipts.flavor", 
                "recipts.prep_time", 
                "recipts.temp", 
                DB::Raw("kind_of_food.name AS clase"), 
                "recipts.image", 
                "recipts.status"
            )
            ->join("kind_of_food", "recipts.i_kind", "=", "kind_of_food.id")
            ->whereNull("recipts.deleted_at")
            ->whereNull("kind_of_food.deleted_at")
            ->get();

            $response = array(
                "error" => true,
                "message" => "Sin error", 
                "data" => $recipts
            );
        } catch ( QueryException $e ) {
            $response = array(
                "error" => true,
                "message" => "Error en la consulta", 
                "data" => $e->getMessage()
            );
        }

        return response()
            ->json($response, 200)
            ->header("Access-Control-Allow-Origin", "*");
    }

    public function getReciptID($id) {
    	$response = array(
            "error" => false,
            "message" => "Sin error"
        );

        try {
            $recipt = Recipts::select(
        		"id", 
                "name",
                "food_time", 
                "flavor", 
                "prep_time", 
                "temp", 
                "i_kind", 
                "image", 
                "status"
        	)
            ->where("id", $id)
            ->get();


            $program = DB::table("program_recipts")
            ->select(
                "program_recipts.id", 
                DB::Raw("programs.id AS iProgram"), 
                "program_recipts.i_recipt", 
                "programs.name"
            )
            ->join("programs", "program_recipts.i_program", "=", "programs.id")
            ->where("program_recipts.i_recipt", $id)
            ->whereNull("programs.deleted_at")
            ->whereNull("program_recipts.deleted_at")
            ->orderBy("programs.id")
            ->get();

            //$program = ProgramRecipts::where("i_recipt", $id)->get();

            $programCalorie = array();
            foreach ( $program as $item ) {
                array_push($programCalorie, $item->id);
            }

            $calorie = CalorieRecipts::select("id", "i_program", "i_calorie")->whereIn("i_program", $programCalorie)->get();

            $calorieIngredientStep = array();
            foreach ( $calorie as $item ) {
                array_push($calorieIngredientStep, $item->id);
            }

            $ingredient = IngredientRecipts::select("id", "i_calorie", "i_ingredient", "portion")->whereIn("i_calorie", $calorieIngredientStep)->get();

            $step = StepsRecipts::select("id", "i_calorie", "step")->whereIn("i_calorie", $calorieIngredientStep)->get();

			$response = array(
                "error" => false,
                "message" => "Sin error", 
                "data" => [
                    "receta" => $recipt, 
                    "programa" => $program,
                    "caloria" => $calorie, 
                    "ingrediente" => $ingredient,
                    "paso" => $step
                ]
            );

        } catch ( QueryException $e ) {
            $response = array(
                "error" => true,
                "message" => "Error en la consulta", 
                "data" => $e->getMessage()
            );
        }

        return response()
            ->json($response, 200)
            ->header("Access-Control-Allow-Origin", "*");
    }

    public function store(Request $r) {
        $response = array(
            "error" => false,
            "message" => "Sin error"
        );

        if ( !is_array($r->ingrediente) || !is_array($r->porcion) || !is_array($r->pasos) ) {
            $response = array(
                "error" => true,
                "message" => "Hay datos faltanes en ingredientes y pasos", 
                "data" => $r->ingrediente
            );

            return response()
                ->json($response, 200)
                ->header("Access-Control-Allow-Origin", "*");
        }
        

        try {
            DB::beginTransaction();

            $recipt = new Recipts();
            $recipt->name = $r->receta;
            $recipt->food_time = $r->tiempo;
            $recipt->flavor = $r->sabor;
            $recipt->prep_time = $r->preparacion;
            $recipt->temp = $r->temp;
            $recipt->i_kind = $r->clase;

            //Files
            if( $r->has("image") ) {
                $fName = $r->file('image');
                $fileName = MD5($fName . uniqid() . microtime()) . "." . $fName->getClientOriginalExtension();
                $r->file('image')->move("img/recetas", $fileName);
                $recipt->image = "/img/recetas/" . $fileName;
            }

            if ( $recipt->save() ) {
                foreach( $r->program as $keyProgram => $itemProgram ) {
                    $ProgramRecipts = new ProgramRecipts();
                    $ProgramRecipts->i_recipt = $recipt->id;
                    $ProgramRecipts->i_program = $itemProgram;
                    $ProgramRecipts->save();
                }

                $pro = ProgramRecipts::where("i_recipt", $recipt->id)->get();

                $program = array();
                foreach( $pro as $key => $item ) {
                    foreach ( $r->calorie[$key] as $k => $i ) {
                        $CalorieRecipts = new CalorieRecipts();
                        $CalorieRecipts->i_program = $item->id;
                        $CalorieRecipts->i_calorie = $i;
                        $CalorieRecipts->save();
                    }
                    array_push($program, $item->id);
                }

                $cal = CalorieRecipts::whereIn("i_program", $program)->get();

                $increment = $cal[0]->id;
                foreach( $pro as $key => $item ) {
                    if ( isset($r->ingrediente[$key]) && isset($r->porcion[$key]) ) {
                        foreach ( $r->ingrediente[$key] as $kI => $itemI ){
                            foreach ( $itemI as $kI2 => $itemI2 ){
                                $IngredientRecipts = new IngredientRecipts();
                                $IngredientRecipts->i_calorie = $increment;
                                $IngredientRecipts->i_ingredient = $itemI2;
                                $IngredientRecipts->portion = number_format($r->porcion[$key][$kI][$kI2], 2, '.', '');
                                $IngredientRecipts->save();
                            }
                            $increment++;
                        }
                    } else {
                        $response = array(
                            "error" => true,
                            "message" => "Hay datos faltanes en ingredientes y pasos", 
                            "data" => $r->ingrediente
                        );

                        return response()
                            ->json($response, 200)
                            ->header("Access-Control-Allow-Origin", "*");
                    }
                }

                $increment = $cal[0]->id;
                foreach( $pro as $key => $item ) {
                    if ( isset($r->pasos[$key]) ) {
                        foreach ( $r->pasos[$key] as $kI => $itemI ){
                            foreach ( $itemI as $kI2 => $itemI2 ){
                                $StepRecipts = new StepsRecipts();
                                $StepRecipts->i_calorie = $increment;
                                $StepRecipts->step = $itemI2;
                                $StepRecipts->save();
                            }
                            $increment++;
                        }
                    } else {
                        $response = array(
                            "error" => true,
                            "message" => "Hay datos faltantes en ingredientes y pasos", 
                            "data" => $r->ingrediente
                        );

                        return response()
                            ->json($response, 200)
                            ->header("Access-Control-Allow-Origin", "*");
                    }
                }

                $response = array(
                    "error" => false,  
                    "message" => "Sin error", 
                    "data" => $r->post()
                );
            } else {
                $response = array(
                    "error" => true,
                    "message" => "Error en la consulta", 
                    "data" => $e->getMessage()
                );
            }
            DB::commit();
        } catch ( QueryException $e ) {
            DB::rollBack();
            if ( $e->getCode() == 23000 ) {
                $response = array(
                    "error" => true,
                    "message" => "Hay calorias con datos faltantes", 
                    "data" => $e->getMessage()
                );
            } else if ( $e->getCode() == 1062) {
                $response = array(
                    "error" => true,
                    "message" => "El nombre de la receta ya existe", 
                    "data" => $e->getMessage()
                );
            } else {
                $response = array(
                    "error" => true,
                    "message" => "Error en la consulta", 
                    "data" => $e->getMessage()
                );
            }
        }

        return response()
            ->json($response, 200)
            ->header("Access-Control-Allow-Origin", "*");
    }

    public function update(Request $r) {
        $response = array(
            "error" => false,
            "message" => "Sin error"
        );

        /** *
        $response = array(
            "error" => true,
            "message" => "Error en la consulta", 
            "data" => $r->post()
        );
 
        return response()
            ->json($response, 200)
            ->header("Access-Control-Allow-Origin", "*");
        /** */

        try {
            DB::beginTransaction();

            $recipt = Recipts::find($r->id);
            $recipt->name = $r->receta;
            $recipt->food_time = $r->tiempo;
            $recipt->flavor = $r->sabor;
            $recipt->prep_time = $r->preparacion;
            $recipt->temp = $r->temp;
            $recipt->i_kind = $r->clase;

            //Files
            if( $r->has("image") ) {
                /* Borrar Mugrero */
                $path = ltrim($recipt->image, '/');
                if ( File::exists($path) ) {
                    unlink( $path );
                }

                $fName = $r->file('image');
                $fileName = MD5($fName . uniqid() . microtime()) . "." . $fName->getClientOriginalExtension();
                $r->file('image')->move("img/recetas", $fileName);
                $recipt->image = "/img/recetas/" . $fileName;
            }

            if ( $recipt->save() ) {

                $Program = ProgramRecipts::select(DB::Raw("GROUP_CONCAT(id) as programas"))->where("i_recipt", $r->id);
                $Calorie = CalorieRecipts::select(DB::Raw("GROUP_CONCAT(id) as calorias"))->whereIn("i_program", explode(",",$Program->get()[0]->programas));
                
                IngredientRecipts::whereIn("i_calorie", explode(",",$Calorie->get()[0]->calorias))->delete();
                StepsRecipts::whereIn("i_calorie", explode(",",$Calorie->get()[0]->calorias))->delete();

                $Program->delete();
                $Calorie->delete();
                /* Borrar Mugrero */

                foreach( $r->program as $keyProgram => $itemProgram ) {
                    $ProgramRecipts = new ProgramRecipts();
                    $ProgramRecipts->i_recipt = $recipt->id;
                    $ProgramRecipts->i_program = $itemProgram;
                    $ProgramRecipts->save();
                }

                $pro = ProgramRecipts::where("i_recipt", $recipt->id)->get();

                $program = array();
                foreach( $pro as $key => $item ) {
                    foreach ( $r->calorie[$key] as $k => $i ) {
                        $CalorieRecipts = new CalorieRecipts();
                        $CalorieRecipts->i_program = $item->id;
                        $CalorieRecipts->i_calorie = $i;
                        $CalorieRecipts->save();
                    }
                    array_push($program, $item->id);
                }

                $cal = CalorieRecipts::whereIn("i_program", $program)->get();

                $increment = $cal[0]->id;
                foreach( $pro as $key => $item ) {
                    foreach ( $r->ingrediente[$key] as $kI => $itemI ){
                        foreach ( $itemI as $kI2 => $itemI2 ){
                            $IngredientRecipts = new IngredientRecipts();
                            $IngredientRecipts->i_calorie = $increment;
                            $IngredientRecipts->i_ingredient = $itemI2;
                            $IngredientRecipts->portion = number_format($r->porcion[$key][$kI][$kI2], 2, '.', '');
                            $IngredientRecipts->save();
                        }
                        $increment++;
                    }
                }

                $increment = $cal[0]->id;
                foreach( $pro as $key => $item ) {
                    foreach ( $r->pasos[$key] as $kI => $itemI ){
                        foreach ( $itemI as $kI2 => $itemI2 ){
                            $StepRecipts = new StepsRecipts();
                            $StepRecipts->i_calorie = $increment;
                            $StepRecipts->step = $itemI2;
                            $StepRecipts->save();
                        }
                        $increment++;
                    }
                }

                $response = array(
                    "error" => false,  
                    "message" => "Sin error", 
                    "data" => $r->post()
                );
            } else {
                $response = array(
                    "error" => true,
                    "message" => "Error en la consulta", 
                    "data" => $e->getMessage()
                );
            }
            DB::commit();
        } catch ( QueryException $e ) {
            DB::rollBack();
            $response = array(
                "error" => true,
                "message" => "Error en la consulta", 
                "data" => $e->getMessage()
            );
        }

        return response()
            ->json($response, 200)
            ->header("Access-Control-Allow-Origin", "*");
    }

    public function delete(Request $r) {
        $response = array(
            "error" => false,
            "message" => "Sin error"
        );

        try {
        	$reciptDelete = Recipts::where('id', $r->id);
            $receta = $reciptDelete->get();

            $programDelete = ProgramRecipts::where('i_recipt', $receta[0]->id);
            $programa = ProgramRecipts::select(DB::Raw("GROUP_CONCAT(id) AS programs"))->where('i_recipt', $receta[0]->id)->get();

            $calorieDelete = CalorieRecipts::whereIn('i_program', explode(",",$programa[0]->programs));
            $caloria = CalorieRecipts::select(DB::Raw("GROUP_CONCAT(id) AS calorias"))->whereIn('i_program', explode(",",$programa[0]->programs))->get();

            $ingredientDelete = IngredientRecipts::whereIn('i_calorie', explode(",",$caloria[0]->calorias));
            $ingrediente = IngredientRecipts::select(DB::Raw("GROUP_CONCAT(id) AS ingredientes"))->whereIn('i_calorie', explode(",",$caloria[0]->calorias))->get();

            $pasoDelete = StepsRecipts::whereIn('i_calorie', explode(",",$caloria[0]->calorias));
            $paso = StepsRecipts::select(DB::Raw("GROUP_CONCAT(id) AS pasos"))->whereIn('i_calorie', explode(",",$caloria[0]->calorias))->get();

			if ( $reciptDelete->delete() && $programDelete->delete() && $calorieDelete->delete() && $ingredientDelete->delete() && $pasoDelete->delete() ) {

                /* Borrar Mugrero */
                $path = ltrim($receta[0]->image, '/');
                if ( File::exists($path) ) {
                    unlink( $path );
                }  

	            $response = array(
	                "error" => false,
	                "message" => "Sin error", 
	                "data" => $receta
	            );
	        } else {
	        	$response = array(
	                "error" => true,
	                "message" => "Error en la consulta", 
	                "data" => $e->getMessage()
	            );
	        }
        } catch ( QueryException $e ) {
            $response = array(
                "error" => true,
                "message" => "Error en la consulta", 
                "data" => $e->getMessage()
            );
        }

        return response()
            ->json($response, 200)
            ->header("Access-Control-Allow-Origin", "*");
    }
}