<?php

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;
// Integraciones
use App\Http\Controllers\Api\Integraciones\Login\AuthController;
use App\Http\Controllers\Api\Integraciones\Registro\RegistroController;

use App\Http\Controllers\Api\Menu\DataController;
use App\Http\Controllers\Api\Profiles\ProfilesController;
use App\Http\Controllers\Api\Users\UsersController;
use App\Http\Controllers\Api\Programs\ProgramsController;
use App\Http\Controllers\Api\Workouts\WorkoutsController;
use App\Http\Controllers\Api\Workouts\WorkoutsVideoController;
use App\Http\Controllers\Api\Inicio\InicioController;
use App\Http\Controllers\Api\Ingredients\IngredientsController;
use App\Http\Controllers\Api\Recipts\ReciptsController;
use App\Http\Controllers\Api\Downloads\DownloadsController;
use App\Http\Controllers\Api\Banners\BannersController;
use App\Http\Controllers\Api\Clientas\ClientasController;
use App\Http\Controllers\Api\Learn\LearnController;
use App\Http\Controllers\Api\Integraciones\Programas\Nutricion\NutricionController;
use App\Http\Controllers\Api\Integraciones\Programas\Workouts\WorkoutController;
use App\Http\Controllers\Api\Integraciones\Plan\PlanController;
use App\Http\Controllers\Api\Integraciones\Tracking\TrackingController;
use App\Http\Controllers\Api\Integraciones\Calorias\CaloriasController;
use App\Http\Controllers\Api\Integraciones\Stripe\StripeController;
use App\Http\Controllers\Api\Integraciones\Paypal\PaypalController;
use App\Http\Controllers\Api\Integraciones\Graficos\GraficosController;
use App\Http\Controllers\Api\Integraciones\Catalogos\CatalogosController;
use App\Http\Controllers\Api\Integraciones\Downloads\DescargasController;
use App\Http\Controllers\Api\Integraciones\Perfil\PerfilController;
use App\Http\Controllers\Api\Integraciones\Newsletter\NewsletterController;

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| is assigned the "api" middleware group. Enjoy building your API!
|
*/

// Integraciones
Route::group(['prefix' => 'auth'], function() {
    Route::post('/login', [AuthController::class, "login"]);
    Route::post('/generate-token', [AuthController::class, "token"]);
    Route::post('/change-password', [AuthController::class, "repassword"]);
    Route::post('/save-customer', [AuthController::class, "saveCustomer"]);
});

Route::group(['prefix' => 'registro'], function() {
    Route::group(['prefix' => 'catalogos'], function() {
        Route::get('/main-goal', [RegistroController::class, "mainGoal"]);
        Route::get('/goal-weight', [RegistroController::class, "goalWeight"]);
        Route::get('/hormonal-disorders', [RegistroController::class, "hormonalDisorders"]);
        Route::get('/physical-activity', [RegistroController::class, "physicalActivity"]);
    });

    Route::get('/planes', [RegistroController::class, "getPlanes"]);
    Route::post('/crear', [RegistroController::class, "registrar"]);
    Route::post('/cuestionario', [RegistroController::class, "cuestionario"]);
    Route::post('/embarazo', [RegistroController::class, "embarazo"]);
    Route::post('/lactancia', [RegistroController::class, "lactancia"]);
    Route::post('/posparto', [RegistroController::class, "posparto"]);
    Route::post('/asignar-plan', [RegistroController::class, "putPlan"]);
    Route::get('/ingredientes', [RegistroController::class, "getIngredientes"]);
});

Route::group(['prefix' => 'programas'], function() {
    Route::get('/nutricion', [NutricionController::class, "index"]);
    Route::get('/workouts', [WorkoutController::class, "index"]);
    Route::get('/catalogos/unidades', [NutricionController::class, "getCatalogUnits"]);

    Route::group(['prefix' => 'nutricion'], function() {
        Route::get('/programa/{id}', [NutricionController::class, "getProgramNutricion"]);
        Route::get('/receta/{cliente}/{receta}', [NutricionController::class, "getRecipt"]);
        Route::get('/detalle/receta/{receta}/{cliente}', [NutricionController::class, "getOriginalRecipt"]);
        Route::get('/lista-compras/{id}', [NutricionController::class, "getShoppingList"]);
        Route::post('/lista-compras', [NutricionController::class, "postShoppingList"]);
        Route::post('/lista-compras-status', [NutricionController::class, "postShoppingListStatus"]);
        Route::get('/recetas/all', [NutricionController::class, "getAllRecipts"]);
        Route::get('/recetas/all/{cliente}', [NutricionController::class, "getAllRecipts"]);
        Route::post('/fechas', [NutricionController::class, "getFechas"]);
        Route::post('/asignar-plan', [NutricionController::class, "putPlan"]);
        Route::get('/recommended-plan/{cliente}', [NutricionController::class, "recommendedPlan"]);
        Route::get('/aleatoria/{cliente}/{tiempo}/{semana}/{dia}/{alimento}', [NutricionController::class, "anotherRecipt"]);
        Route::get('/aleatorio/ingrediente/{cliente}/{receta}/{ingrediente}', [NutricionController::class, "anotherIngredient"]);
    });

    Route::group(['prefix' => 'workout'], function() {
        Route::get('/programa/{id}', [WorkoutController::class, "getProgramWorkout"]);
        Route::get('/detalle/{id}', [WorkoutController::class, "getProgramWorkoutDetalle"]);
        Route::get('/on-demand', [WorkoutController::class, "getWorkoutOnDemand"]);
        Route::get('/video/{id}', [WorkoutController::class, "getWorkoutVideo"]);
        Route::post('/asignar-plan', [WorkoutController::class, "putPlan"]);
    });
});

Route::group(['prefix' => 'plan'], function() {
    Route::get('/hoy/{id}', [PlanController::class, "getPlan"]);
    Route::get('/semanal/{id}', [PlanController::class, "getWeekPlan"]);
    Route::get('/imprimir-plan/{cliente}/{posicion}', [PlanController::class, "imprimirPlan"]);
    Route::get('/reprocess-shopping-list/{cliente}', [PlanController::class, "reprocessShoppingList"]);
});

Route::group(['prefix' => 'tracking'], function() {
    Route::get('/categories', [TrackingController::class, "getTrackingCatCategories"]);
    Route::get('/mood', [TrackingController::class, "getTrackingCatMood"]);
    Route::get('/supplements', [TrackingController::class, "getTrackingCatSupplements"]);

    Route::post('/inputs', [TrackingController::class, "storeTrackingItems"]);
    Route::get('/inputs/{id}', [TrackingController::class, "getTrackingItems"]);
    
    /* Tracking Weight */
    Route::post('/weight', [TrackingController::class, "storeTrackingWeight"]);
    Route::get('/weight/{id}', [TrackingController::class, "getTrackingWeight"]);

    /* Tracking Water */
    Route::post('/water', [TrackingController::class, "storeTrackingWater"]);
    Route::get('/water/{id}', [TrackingController::class, "getTrackingWater"]);

    /* Tracking Exercise */
    Route::post('/exercise', [TrackingController::class, "storeTrackingExercise"]);
    Route::get('/exercise/{id}', [TrackingController::class, "getTrackingExercise"]);

    /* Tracking Nutrition */
    Route::post('/nutrition', [TrackingController::class, "storeTrackingNutrition"]);
    Route::get('/nutrition/{id}', [TrackingController::class, "getTrackingNutrition"]);

    /* Tracking Sleep */
    Route::post('/sleep', [TrackingController::class, "storeTrackingSleep"]);
    Route::get('/sleep/{id}', [TrackingController::class, "getTrackingSleep"]);

    /* Tracking Mood */
    Route::post('/mood', [TrackingController::class, "storeTrackingMood"]);
    Route::get('/mood/{id}', [TrackingController::class, "getTrackingMood"]);

    /* Tracking Energy */
    Route::post('/energy', [TrackingController::class, "storeTrackingEnergy"]);
    Route::get('/energy/{id}', [TrackingController::class, "getTrackingEnergy"]);

    /* Tracking Supplements */
    Route::post('/supplement', [TrackingController::class, "storeSupplement"]);
    Route::post('/supplements', [TrackingController::class, "storeTrackingSupplements"]);
    Route::get('/supplements/{id}', [TrackingController::class, "getTrackingSupplements"]);

    /* Tracking Meditation */
    Route::post('/meditation', [TrackingController::class, "storeTrackingMeditation"]);
    Route::get('/meditation/{id}', [TrackingController::class, "getTrackingMeditation"]);

    /* Tracking Menstrual Cycle */
    Route::post('/cycle', [TrackingController::class, "storeTrackingMenstrualCycle"]);
    Route::get('/cycle/{id}', [TrackingController::class, "getTrackingMenstrualCycle"]);
});

Route::group(['prefix' => 'grafico'], function() {
    Route::get('/medidas/{cliente}', [ GraficosController::class, "getMedidas" ]);
    Route::get('/agua/{cliente}', [ GraficosController::class, "getAgua" ]);
    Route::get('/ejercicio/{cliente}', [ GraficosController::class, "getEjercicio" ]);
    Route::get('/nutricion/{cliente}', [ GraficosController::class, "getNutricion" ]);
    Route::get('/sueno/{cliente}', [ GraficosController::class, "getSueno" ]);
    Route::get('/animo/{cliente}', [ GraficosController::class, "getAnimo" ]);
    Route::get('/energia/{cliente}', [ GraficosController::class, "getEnergia" ]);
    Route::get('/suplementos/{cliente}', [ GraficosController::class, "getSuplementos" ]);
    Route::get('/meditacion/{cliente}', [ GraficosController::class, "getMeditacion" ]);
    Route::get('/ciclo/{cliente}', [ GraficosController::class, "getCiclo" ]);
});

Route::group(['prefix' => 'calorias'], function() {
    //Route::get('/calcular/{id}', [CaloriasController::class, "calcularCalorias"]);
    Route::post('/calcular', [CaloriasController::class, "updateCalorias"]);
});

Route::group(['prefix' => 'stripe'], function() {
    Route::post('/create-customer', [StripeController::class, "crearStripeCustomer"]);
    Route::post('/set-payment', [StripeController::class, "setStripePayment"]);
    Route::post('/customer-subscribe', [StripeController::class, "customerSubscribe"]);
});

Route::group(['prefix' => 'paypal'], function() {
    Route::post('/save-subscription', [PaypalController::class, "saveSubscription"]);
});

Route::group(['prefix' => 'catalogos'], function() {
    Route::get('/registro/meta-principal', [CatalogosController::class, "getMetaPrincipal"]);
    Route::get('/registro/meta-peso', [CatalogosController::class, "getMetaPeso"]);
    Route::get('/registro/hormonal', [CatalogosController::class, "getHormonal"]);
    Route::get('/registro/animo', [CatalogosController::class, "getAnimo"]);
    Route::get('/registro/actividad', [CatalogosController::class, "getActividad"]);
    Route::get('/registro/suplementos', [CatalogosController::class, "getSuplementos"]);
});

Route::group(['prefix' => 'downloads'], function() {
    Route::get('/catalogo', [DescargasController::class, "getDownloads"]);
    Route::get('/catalogo/{id}', [DescargasController::class, "getDownload"]);
});

Route::group(['prefix' => 'perfil'], function() {
    Route::get('/mi-perfil/{id}', [PerfilController::class, "getPerfil"]);
    Route::post('/mi-perfil', [PerfilController::class, "updatePerfil"]);

    Route::get('/datos-salud/{id}', [PerfilController::class, "getDatosSalud"]);
    Route::post('/datos-salud', [PerfilController::class, "updateDatosSalud"]); 

    Route::get('/suscripcion/{id}', [PerfilController::class, "getSuscripcion"]);
    Route::post('/suscripcion/editar', [PerfilController::class, "updateSuscripcion"]); 
    Route::post('/suscripcion/cancelar', [PerfilController::class, "cancelSuscripcion"]); 

    Route::get('/cancelaciones-tipo', [PerfilController::class, "getCancelacionesType"]);

    Route::post("/update-pregnancy", [PerfilController::class, "updatePregnancy"]);
});

Route::group(['prefix' => 'newsletter'], function() {
    Route::post('/save', [NewsletterController::class, "save"]);
});

Route::group(['prefix' => 'learn'], function() {
    Route::group(['prefix' => 'data'], function() {
        Route::get('categorias', [ LearnController::class, "getDataCategorias" ] );
        Route::get('{id}/videos', [ LearnController::class, "getDataCategoriasVideos" ] );
    });
});


// Admin
Route::prefix("inicio")->group(function() {
    Route::post( 'login', [ InicioController::class, "login" ] );
    Route::post( 'recovery', [ InicioController::class, "recovery" ] );
});

Route::prefix("menu")->group(function() {
    Route::get( 'get-menu', [ DataController::class, "getMenu" ] );
});

Route::prefix("perfiles")->group(function() {
    Route::get('get-profiles', [ ProfilesController::class, "getProfiles" ] );
    Route::get('get-profile/{id}', [ ProfilesController::class, "getProfileID" ] );
    Route::post('store', [ ProfilesController::class, "store" ] );
    Route::post('update', [ ProfilesController::class, "update" ] );
    Route::delete('delete/{id}', [ ProfilesController::class, "delete" ] );
});

Route::prefix("users")->group(function() {
    Route::get('get-users', [ UsersController::class, "getUsers" ] );
    Route::get('get-user/{id}', [ UsersController::class, "getUserID" ] );
    Route::post('store', [ UsersController::class, "store" ] );
    Route::post('update', [ UsersController::class, "update" ] );
    Route::delete('delete/{id}', [ UsersController::class, "delete" ] );
});

Route::prefix("programs")->group(function() {
    Route::get('get-programs', [ ProgramsController::class, "getPrograms" ] );
    Route::get('get-program/{id}', [ ProgramsController::class, "getProgramID" ] );
    Route::post('store', [ ProgramsController::class, "store" ] );
    Route::post('update', [ ProgramsController::class, "update" ] );
    Route::delete('delete/{id}', [ ProgramsController::class, "delete" ] );
});

Route::prefix("workouts")->group(function() {
    Route::get('get-workouts', [ WorkoutsController::class, "getworkouts" ] );
    Route::get('get-workout/{id}', [ WorkoutsController::class, "getworkoutID" ] );
    Route::post('store', [ WorkoutsController::class, "store" ] );
    Route::post('update', [ WorkoutsController::class, "update" ] );
    Route::delete('delete/{id}', [ WorkoutsController::class, "delete" ] );
});

Route::prefix("workouts-video")->group(function() {
    Route::get('get-workouts-video/{id}', [ WorkoutsVideoController::class, "getworkoutsvideo" ] );
    Route::post('store', [ WorkoutsVideoController::class, "store" ] );
});

Route::prefix("ingredients")->group(function() {
    Route::get('get-ingredients', [ IngredientsController::class, "getIngredients" ] );
    Route::get('get-cat-ingredients', [ IngredientsController::class, "getCatIngredients" ] );
    Route::get('get-cat-units', [ IngredientsController::class, "getCatUnits" ] );
    Route::get('get-ingredient/{id}', [ IngredientsController::class, "getIngredientID" ] );
    Route::post('store', [ IngredientsController::class, "store" ] );
    Route::post('update', [ IngredientsController::class, "update" ] );
    Route::delete('delete/{id}', [ IngredientsController::class, "delete" ] );
});

Route::prefix("recipts")->group(function() {
    Route::get('get-kindfood', [ ReciptsController::class, "getKindFood" ] );
    Route::get('get-recipts', [ ReciptsController::class, "getRecipts" ] );
    Route::get('get-recipt/{id}', [ ReciptsController::class, "getReciptID" ] );
    Route::post('store', [ ReciptsController::class, "store" ] );
    Route::post('update', [ ReciptsController::class, "update" ] );
    Route::delete('delete/{id}', [ ReciptsController::class, "delete" ] );
});

Route::prefix("banners")->group(function() {
    Route::get('get-banners', [ BannersController::class, "getBanners" ] );
    Route::get('get-banner/{id}', [ BannersController::class, "getBannerID" ] );
    Route::post('store', [ BannersController::class, "store" ] );
    Route::post('update', [ BannersController::class, "update" ] );
    Route::delete('delete/{id}', [ BannersController::class, "delete" ] );
});

Route::prefix("downloads")->group(function() {
    Route::get('get-downloads', [ DownloadsController::class, "getDownloads" ] );
    Route::get('get-download/{id}', [ DownloadsController::class, "getDownloadID" ] );
    Route::post('store', [ DownloadsController::class, "store" ] );
    Route::post('update', [ DownloadsController::class, "update" ] );
    Route::delete('delete/{id}', [ DownloadsController::class, "delete" ] );
});

Route::prefix("clientas")->group(function() {
    Route::get('get-clientas', [ ClientasController::class, "getClientas" ] );
});

Route::group(['prefix' => 'learn'], function() {
    Route::group(['prefix' => 'categorias'], function() {
        Route::get('get', [ LearnController::class, "getCategorias" ] );
        Route::get('get/{id}', [ LearnController::class, "getCategoriaID" ] );
        Route::post('store/', [ LearnController::class, "storeCategorias" ] );
        Route::post('update/', [ LearnController::class, "updateCategorias" ] );
        Route::delete('delete/{id}', [ LearnController::class, "deleteCategorias" ] );
    });
    Route::group(['prefix' => 'videos'], function() {
        Route::get('get', [ LearnController::class, "getVideos" ] );
        Route::get('get/{id}', [ LearnController::class, "getVideoID" ] );
        Route::post('store/', [ LearnController::class, "storVideos" ] );
        Route::post('update/', [ LearnController::class, "updateVideos" ] );
        Route::delete('delete/{id}', [ LearnController::class, "deleteVideos" ] );
    });
});